PleaseLinkData = PleaseLinkData or {}

-- content patches of when something was released - spaced out values in case more are needed
PleaseLinkData.Content = {T4=10, T5=20, T6=30, ZA=40, SW=50}
local Content = PleaseLinkData.Content

-- The possible craft spell prefixes - to build proper links since these aren't in the spell names
PleaseLinkData.CraftPrefix = {
	ALCHEMY        = "Alchemy: ",
	BLACKSMITHING  = "Blacksmithing: ",
	COOKING        = "Cooking: ",
	ENCHANTING     = "Enchanting: ", -- only used for crafts like mana oil, not direct enchantments
	ENGINEERING    = "Engineering: ",
	FIRSTAID       = "First Aid: ",
	JEWELCRAFTING  = "Jewelcrafting: ",
	LEATHERWORKING = "Leatherworking: ",
	SMELTING       = "Mining: ",
	TAILORING      = "Tailoring: ",
}
local CraftPrefix = PleaseLinkData.CraftPrefix

-- list of professions used to detect when someone from WotLK or later asks you to link a profession
PleaseLinkData.professionNames = {
	alchemy        = 1,
	blacksmithing  = 1,
	cooking        = 1,
	enchanting     = 1,
	engineering    = 1,
	jewelcrafting  = 1,
	leatherworking = 1,
	tailoring      = 1,
}

-- used to convert common shorthand and messed up words into ones used in the craftKeywordList tables
PleaseLinkData.keywordFixes = {
	-- major keywords
	bombs        = "bomb",
	grenade      = "bomb",
	grenades     = "bomb",
	boot         = "boots",
	feet         = "boots",
	feets        = "boots",
	foot         = "boots",
	foots        = "boots",
	shoe         = "boots",
	shoes        = "boots",
	brace        = "bracer",
	bracers      = "bracer",
	wrist        = "bracer",
	wrists       = "bracer",
	wrst         = "bracer",
	wrsts        = "bracer",
	body         = "chest",
	chst         = "chest",
	back         = "cloak",
	cape         = "cloak",
	cooking      = "food",
	gems         = "gem",
	jewel        = "gem",
	socket       = "gem",
	sockets      = "gem",
	glove        = "gloves",
	hand         = "gloves",
	hands        = "gloves",
	leg          = "legs",
	pant         = "legs",
	pants        = "legs",
	finger       = "ring",
	fingers      = "ring",
	rings        = "ring",
	gear         = "set",
	axe          = "weapon",
	axes         = "weapon",
	dagger       = "weapon",
	daggers      = "weapon",
	staff        = "weapon",
	sword        = "weapon",
	swords       = "weapon",
	wapon        = "weapon",
	wea          = "weapon",
	weap         = "weapon",
	weapin       = "weapon",
	weapn        = "weapon",
	weapons      = "weapon",
	wep          = "weapon",
	wepn         = "weapon",
	wepon        = "weapon",
	wpn          = "weapon",

	-- base stats
	ag           = "agility",
	agi          = "agility",
	agil         = "agility",
	arm          = "armor",
	armour       = "armor",
	int          = "intellect",
	intel        = "intellect",
	intelect     = "intellect",
	intelli      = "intellect",
	intelligence = "intellect",
	spi          = "spirit",
	spir         = "spirit",
	st           = "stamina",
	sta          = "stamina",
	stam         = "stamina",
	stami        = "stamina",
	str          = "strength",
	stre         = "strength",
	stren        = "strength",
	strenght     = "strength",
	-- elements
	arc          = "arcane",
	fir          = "fire",
	fr           = "frost",
	fro          = "frost",
	nat          = "nature",
	sha          = "shadow",
	shad         = "shadow",
	-- miscellaneous
	at           = "attack",
	atk          = "attack",
	att          = "attack",
	attk         = "attack",
	blacksmith   = "blacksmithing",
	bs           = "blacksmithing",
	crit         = "critical",
	criti        = "critical",
	critic       = "critical",
	dam          = "damage",
	dmg          = "damage",
	def          = "defense",
	defence      = "defense",
	eli          = "elixir",
	elix         = "elixir",
	elixer       = "elixir",
	elx          = "elixir",
	ench         = "enchant",
	enchantment  = "enchant",
	enchantments = "enchant",
	enchants     = "enchant",
	enchs        = "enchant",
	healer       = "heal",
	healin       = "heal",
	healing      = "heal",
	heals        = "heal",
	hel          = "heal",
	hp           = "health",
	leatherwork  = "leatherworking",
	lw           = "leatherworking",
	maj          = "major",
	manas        = "mana",
	mp           = "mana",
	mongose      = "mongoose",
	moongoose    = "mongoose",
	moongose     = "mongoose",
	pen          = "penetration",
	pene         = "penetration",
	penatrate    = "penetration",
	melee        = "physical",
	phy          = "physical",
	phys         = "physical",
	physi        = "physical",
	pys          = "physical",
	pysi         = "physical",
	range        = "physical",
	ranged       = "physical",
	pot          = "potion",
	potions      = "potion",
	pots         = "potion",
	pow          = "power",
	powr         = "power",
	pwr          = "power",
	pro          = "profession",
	prof         = "profession",
	proff        = "profession",
	-- res shouldn't be corrected - it's on both resistance and resilience things
	resi         = "resilience",
	resil        = "resilience",
	resili       = "resilience",
	resis        = "resistance",
	resist       = "resistance",
	resistant    = "resistance",
	resistence   = "resistance",
	resists      = "resistance",
	sheild       = "shield",
	spel         = "spell",
	spl          = "spell",
	spelcrit     = "spellcrit",
	splcrit      = "spellcrit",
	sd           = "spelldamage",
	spd          = "spelldamage",
	spdam        = "spelldamage",
	spdamage     = "spelldamage",
	spdmg        = "spelldamage",
	speldam      = "spelldamage",
	speldamage   = "spelldamage",
	speldmg      = "spelldamage",
	spelldam     = "spelldamage",
	spelldmg     = "spelldamage",
	spldam       = "spelldamage",
	spldamage    = "spelldamage",
	spldmg       = "spelldamage",
	spellp       = "spellpower",
	spellpo      = "spellpower",
	spellpow     = "spellpower",
	spellpowe    = "spellpower",
	spellpowr    = "spellpower",
	spellpwer    = "spellpower",
	spellpwr     = "spellpower",
	spelpower    = "spellpower",
	splpow       = "spellpower",
	splpower     = "spellpower",
	splpwr       = "spellpower",
	spelhit      = "spellhit",
	sphit        = "spellhit",
	splhit       = "spellhit",
	splpen       = "spen",
	sppen        = "spen",
	stat         = "stats",
}

-- The craftable things in this table are split up among major keywords. For example, all boot
-- enchantments are in the "boots" table.
-- Format: {spell ID, if just a single minor keyword can match, content level, CraftPrefix or nil, {keyword=1, keyword=1, ...}}
-- "if just a single minor keyword can match" is for making "link mongoose" work but "link stats" won't
-- Special rules: res should be added to both resilience and resistance things
--                it's OK if things are listed twice in different ways (like single minor keyword matching things are)
PleaseLinkData.craftKeywordList = {
	----------------------------------------
	-- Miscellaneous
	----------------------------------------
	["BAG"] = { -- capatalized to not be a major keyword
		--[[Bag of Enchantment     ]] {27660, false, Content.T4, CraftPrefix.TAILORING,      {bag=1, bags=1, slot=1, slots=1, ["24"]=1, enchanting=1, enchanter=1, enchanters=1, enchant=1}},
		--[[Bag of Jewels          ]] {31459, false, Content.T4, CraftPrefix.TAILORING,      {bag=1, bags=1, slot=1, slots=1, ["24"]=1, jewels=1, jewel=1, jewelcrafting=1, jewelcrafter=1, jewelcrafters=1}},
		--[[Bag of Many Hides      ]] {45117, false, Content.T4, CraftPrefix.LEATHERWORKING, {bag=1, bags=1, slot=1, slots=1, ["24"]=1, many=1, hides=1, hide=1, leatherworker=1, leatherworkers=1, leatherworking=1}},
		--[[Cenarion Herb Bag      ]] {27724, false, Content.T4, CraftPrefix.TAILORING,      {bag=1, bags=1, slot=1, slots=1, ["20"]=1, cenarion=1, herb=1, herbs=1, herbalism=1, herbalist=1, herbalists=1}},
		--[[Core Felcloth Bag      ]] {26087, false, Content.T4, CraftPrefix.TAILORING,      {bag=1, bags=1, slot=1, slots=1, ["28"]=1, core=1, felcloth=1, warlock=1, warlocks=1, lock=1}},
		--[[Ebon Shadow Bag        ]] {26759, false, Content.T4, CraftPrefix.TAILORING,      {bag=1, bags=1, slot=1, slots=1, ["28"]=1, ebon=1, shadow=1, warlock=1, warlocks=1, lock=1}},
		--[[Enchanted Runecloth    ]] {27659, false, Content.T4, CraftPrefix.TAILORING,      {bag=1, bags=1, slot=1, slots=1, ["20"]=1, runecloth=1, rune=1, cloth=1, enchanting=1, enchanter=1, enchanters=1, enchant=1}},
		--[[Felcloth Bag           ]] {26086, false, Content.T4, CraftPrefix.TAILORING,      {bag=1, bags=1, slot=1, slots=1, ["24"]=1, felcloth=1, warlock=1, warlocks=1, lock=1}},
		--[[Imbued Netherweave Bag ]] {26749, false, Content.T4, CraftPrefix.TAILORING,      {bag=1, bags=1, slot=1, slots=1, ["18"]=1, imbued=1, netherweave=1}},
		--[[Leatherworker's Satchel]] {45100, false, Content.T4, CraftPrefix.LEATHERWORKING, {bag=1, bags=1, slot=1, slots=1, ["20"]=1, leatherworker=1, leatherworkers=1, leatherworking=1, satchel=1}},
		--[[Mycah's Botanical Bag  ]] {50194, false, Content.T4, CraftPrefix.TAILORING,      {bag=1, bags=1, slot=1, slots=1, ["24"]=1, mycah=1, botanical=1, herb=1, herbs=1, herbalism=1, herbalist=1, herbalists=1}},
		--[[Netherweave Bag        ]] {26746, false, Content.T4, CraftPrefix.TAILORING,      {bag=1, bags=1, slot=1, slots=1, ["16"]=1, netherweave=1}},
		--[[Primal Mooncloth Bag   ]] {26763, false, Content.T4, CraftPrefix.TAILORING,      {bag=1, bags=1, slot=1, slots=1, ["20"]=1, primal=1, mooncloth=1, moon=1, cloth=1}},
		--[[Reinforced Mining Bag  ]] {35530, false, Content.T4, CraftPrefix.LEATHERWORKING, {bag=1, bags=1, slot=1, slots=1, ["28"]=1, reinforced=1, mining=1, miner=1, miners=1}},
		--[[Satchel of Cenarius    ]] {27725, false, Content.T4, CraftPrefix.TAILORING,      {bag=1, bags=1, slot=1, slots=1, ["24"]=1, satchel=1, cenarius=1, herb=1, herbs=1, herbalism=1, herbalist=1, herbalists=1}},
		--[[Spellfire Bag          ]] {26755, false, Content.T4, CraftPrefix.TAILORING,      {bag=1, bags=1, slot=1, slots=1, ["28"]=1, spellfire=1, spell=1, fire=1, enchanting=1, enchanter=1, enchanters=1, enchant=1}},
		--[[Fel Iron Toolbox       ]] {30348, false, Content.T4, CraftPrefix.ENGINEERING,    {bag=1, bags=1, slot=1, slots=1, ["24"]=1, fel=1, iron=1, toolbox=1, engineering=1, engineer=1, engi=1}},
	},
	["set"] = { -- sets are searched for specifically, so content is set to the lowest even when it comes out later
		-- Shadow Resistance
		-- Plate:
		--[[shadesteel sabots           ]] {40033, false, Content.T4, CraftPrefix.BLACKSMITHING,  {shadow=1, resistance=1, res=1, shadesteel=1, plate=1, blacksmithing=1}},
		--[[shadesteel greaves          ]] {40035, false, Content.T4, CraftPrefix.BLACKSMITHING,  {shadow=1, resistance=1, res=1, shadesteel=1, plate=1, blacksmithing=1}},
		--[[shadesteel girdle           ]] {40036, false, Content.T4, CraftPrefix.BLACKSMITHING,  {shadow=1, resistance=1, res=1, shadesteel=1, plate=1, blacksmithing=1}},
		--[[shadesteel bracers          ]] {40034, false, Content.T4, CraftPrefix.BLACKSMITHING,  {shadow=1, resistance=1, res=1, shadesteel=1, plate=1, blacksmithing=1}},
		-- Mail:
		--[[waistguard of shackled souls]] {40002, false, Content.T4, CraftPrefix.LEATHERWORKING, {shadow=1, resistance=1, res=1, shackled=1, soul=1, souls=1, leatherworking=1, mail=1}},
		--[[greaves of shackled souls   ]] {40001, false, Content.T4, CraftPrefix.LEATHERWORKING, {shadow=1, resistance=1, res=1, shackled=1, soul=1, souls=1, leatherworking=1, mail=1}},
		--[[bracers of shackled souls   ]] {40000, false, Content.T4, CraftPrefix.LEATHERWORKING, {shadow=1, resistance=1, res=1, shackled=1, soul=1, souls=1, leatherworking=1, mail=1}},
		--[[boots of shackled souls     ]] {39997, false, Content.T4, CraftPrefix.LEATHERWORKING, {shadow=1, resistance=1, res=1, shackled=1, soul=1, souls=1, leatherworking=1, mail=1}},
		--LEATHER:
		--[[redeemed soul wristguards   ]] {40004, false, Content.T4, CraftPrefix.LEATHERWORKING, {shadow=1, resistance=1, res=1, redeemed=1, soul=1, leatherworking=1, leather=1}},
		--[[redeemed soul moccasins     ]] {40003, false, Content.T4, CraftPrefix.LEATHERWORKING, {shadow=1, resistance=1, res=1, redeemed=1, soul=1, leatherworking=1, leather=1}},
		--[[redeemed soul legguards     ]] {40005, false, Content.T4, CraftPrefix.LEATHERWORKING, {shadow=1, resistance=1, res=1, redeemed=1, soul=1, leatherworking=1, leather=1}},
		--[[redeemed soul cinch         ]] {40006, false, Content.T4, CraftPrefix.LEATHERWORKING, {shadow=1, resistance=1, res=1, redeemed=1, soul=1, leatherworking=1, leather=1}},
		-- Cloth:
		--[[soulguard slippers          ]] {40020, false, Content.T4, CraftPrefix.TAILORING,      {shadow=1, resistance=1, res=1, soulguard=1, tailoring=1, tailor=1, cloth=1}},
		--[[soulguard leggings          ]] {40023, false, Content.T4, CraftPrefix.TAILORING,      {shadow=1, resistance=1, res=1, soulguard=1, tailoring=1, tailor=1, cloth=1}},
		--[[soulguard girdle            ]] {40024, false, Content.T4, CraftPrefix.TAILORING,      {shadow=1, resistance=1, res=1, soulguard=1, tailoring=1, tailor=1, cloth=1}},
		--[[soulguard bracers           ]] {40021, false, Content.T4, CraftPrefix.TAILORING,      {shadow=1, resistance=1, res=1, soulguard=1, tailoring=1, tailor=1, cloth=1}},
		-- Cloak:
		--[[night's end                 ]] {40060, false, Content.T4, CraftPrefix.TAILORING,      {shadow=1, resistance=1, res=1, tailoring=1, tailor=1, cloth=1, leatherworking=1, leather=1, mail=1, plate=1, blacksmithing=1}},

		-- Fire Resistance
		-- Plate
		--[[flamebane helm       ]] {29615, false, Content.T4, CraftPrefix.BLACKSMITHING,  {fire=1, resistance=1, res=1, flamebane=1, blacksmithing=1, plate=1}},
		--[[flamebane bracers    ]] {29614, false, Content.T4, CraftPrefix.BLACKSMITHING,  {fire=1, resistance=1, res=1, flamebane=1, blacksmithing=1, plate=1}},
		--[[flamebane gloves     ]] {29616, false, Content.T4, CraftPrefix.BLACKSMITHING,  {fire=1, resistance=1, res=1, flamebane=1, blacksmithing=1, plate=1}},
		--[[flamebane breastplate]] {29617, false, Content.T4, CraftPrefix.BLACKSMITHING,  {fire=1, resistance=1, res=1, flamebane=1, blacksmithing=1, plate=1}},
		-- Mail
		--[[flamescale leggings  ]] {35529, false, Content.T4, CraftPrefix.LEATHERWORKING, {fire=1, resistance=1, res=1, flamescale=1, leatherworking=1, mail=1}},
		--[[flamescale boots     ]] {35528, false, Content.T4, CraftPrefix.LEATHERWORKING, {fire=1, resistance=1, res=1, flamescale=1, leatherworking=1, mail=1}},
		--[[flamescale belt      ]] {35531, false, Content.T4, CraftPrefix.LEATHERWORKING, {fire=1, resistance=1, res=1, flamescale=1, leatherworking=1, mail=1}},
		-- Leather
		--[[blastguard pants     ]] {35535, false, Content.T4, CraftPrefix.LEATHERWORKING, {fire=1, resistance=1, res=1, blastguard=1, leatherworking=1, leather=1}},
		--[[blastguard boots     ]] {35536, false, Content.T4, CraftPrefix.LEATHERWORKING, {fire=1, resistance=1, res=1, blastguard=1, leatherworking=1, leather=1}},
		--[[blastguard belt      ]] {35537, false, Content.T4, CraftPrefix.LEATHERWORKING, {fire=1, resistance=1, res=1, blastguard=1, leatherworking=1, leather=1}},
		-- Cloth
		--[[flameheart vest      ]] {37884, false, Content.T4, CraftPrefix.TAILORING,      {fire=1, resistance=1, res=1, flameheart=1, tailoring=1, tailor=1, cloth=1}},
		--[[flameheart gloves    ]] {37883, false, Content.T4, CraftPrefix.TAILORING,      {fire=1, resistance=1, res=1, flameheart=1, tailoring=1, tailor=1, cloth=1}},
		--[[flameheart bracers   ]] {37882, false, Content.T4, CraftPrefix.TAILORING,      {fire=1, resistance=1, res=1, flameheart=1, tailoring=1, tailor=1, cloth=1}},

		-- Frost Resistance
		-- Plate
		--[[iceguard leggings   ]] {38478, false, Content.T4, CraftPrefix.BLACKSMITHING, {frost=1, resistance=1, res=1, iceguard=1, blacksmithing=1, plate=1}},
		--[[iceguard helm       ]] {38479, false, Content.T4, CraftPrefix.BLACKSMITHING, {frost=1, resistance=1, res=1, iceguard=1, blacksmithing=1, plate=1}},
		--[[iceguard breastplate]] {38477, false, Content.T4, CraftPrefix.BLACKSMITHING, {frost=1, resistance=1, res=1, iceguard=1, blacksmithing=1, plate=1}},

		-- Nature Resistance
		-- Plate
		--[[wildguard leggings   ]] {38475, false, Content.T4, CraftPrefix.BLACKSMITHING, {nature=1, resistance=1, res=1, wildguard=1, blacksmithing=1, plate=1}},
		--[[wildguard helm       ]] {38476, false, Content.T4, CraftPrefix.BLACKSMITHING, {nature=1, resistance=1, res=1, wildguard=1, blacksmithing=1, plate=1}},
		--[[wildguard breastplate]] {38473, false, Content.T4, CraftPrefix.BLACKSMITHING, {nature=1, resistance=1, res=1, wildguard=1, blacksmithing=1, plate=1}},

		-- Arcane Resistance
		-- Plate
		--[[enchanted adamantite leggings   ]] {29613, false, Content.T4, CraftPrefix.BLACKSMITHING,  {arcane=1, resistance=1, res=1, enchanted=1, adamantite=1, blacksmithing=1, plate=1}},
		--[[enchanted adamantite breastplate]] {29610, false, Content.T4, CraftPrefix.BLACKSMITHING,  {arcane=1, resistance=1, res=1, enchanted=1, adamantite=1, blacksmithing=1, plate=1}},
		--[[enchanted adamantite boots      ]] {29611, false, Content.T4, CraftPrefix.BLACKSMITHING,  {arcane=1, resistance=1, res=1, enchanted=1, adamantite=1, blacksmithing=1, plate=1}},
		--[[enchanted adamantite belt       ]] {29608, false, Content.T4, CraftPrefix.BLACKSMITHING,  {arcane=1, resistance=1, res=1, enchanted=1, adamantite=1, blacksmithing=1, plate=1}},
		-- Mail
		--[[enchanted felscale leggings     ]] {35525, false, Content.T4, CraftPrefix.LEATHERWORKING, {arcane=1, resistance=1, res=1, enchanted=1, felscale=1, leatherworking=1, mail=1}},
		--[[enchanted felscale gloves       ]] {35526, false, Content.T4, CraftPrefix.LEATHERWORKING, {arcane=1, resistance=1, res=1, enchanted=1, felscale=1, leatherworking=1, mail=1}},
		--[[enchanted felscale boots        ]] {35527, false, Content.T4, CraftPrefix.LEATHERWORKING, {arcane=1, resistance=1, res=1, enchanted=1, felscale=1, leatherworking=1, mail=1}},
		-- Leather
		--[[enchanted clefthoof leggings    ]] {35532, false, Content.T4, CraftPrefix.LEATHERWORKING, {arcane=1, resistance=1, res=1, enchanted=1, clefthoof=1, leatherworking=1, leather=1}},
		--[[enchanted clefthoof gloves      ]] {35533, false, Content.T4, CraftPrefix.LEATHERWORKING, {arcane=1, resistance=1, res=1, enchanted=1, clefthoof=1, leatherworking=1, leather=1}},
		--[[enchanted clefthoof boots       ]] {35534, false, Content.T4, CraftPrefix.LEATHERWORKING, {arcane=1, resistance=1, res=1, enchanted=1, clefthoof=1, leatherworking=1, leather=1}},
		-- Cloth
		--[[soulcloth vest                  ]] {26781, false, Content.T4, CraftPrefix.TAILORING,      {arcane=1, resistance=1, res=1, soulcloth=1, tailoring=1, tailor=1, cloth=1}},
		--[[soulcloth shoulders             ]] {26780, false, Content.T4, CraftPrefix.TAILORING,      {arcane=1, resistance=1, res=1, soulcloth=1, tailoring=1, tailor=1, cloth=1}},
		--[[soulcloth gloves                ]] {26779, false, Content.T4, CraftPrefix.TAILORING,      {arcane=1, resistance=1, res=1, soulcloth=1, tailoring=1, tailor=1, cloth=1}},
		--[[arcanoweave robe                ]] {26784, false, Content.T4, CraftPrefix.TAILORING,      {arcane=1, resistance=1, res=1, arcanoweave=1, tailoring=1, tailor=1, cloth=1}},
		--[[arcanoweave boots               ]] {26783, false, Content.T4, CraftPrefix.TAILORING,      {arcane=1, resistance=1, res=1, arcanoweave=1, tailoring=1, tailor=1, cloth=1}},
		--[[arcanoweave bracers             ]] {26782, false, Content.T4, CraftPrefix.TAILORING,      {arcane=1, resistance=1, res=1, arcanoweave=1, tailoring=1, tailor=1, cloth=1}},
		-- Cloak
		--[[cloak of arcane evasion         ]] {37873, false, Content.T4, CraftPrefix.TAILORING,      {arcane=1, resistance=1, res=1, tailoring=1, tailor=1, cloth=1, leatherworking=1, leather=1, mail=1, plate=1, blacksmithing=1}},

		-- Miscellaneous
		-- Tuxedo
		--[[tuxedo jacket           ]] {12093, false, Content.T4, CraftPrefix.TAILORING,      {tuxedo=1, tailoring=1, tailor=1}},
		--[[tuxedo pants            ]] {12089, false, Content.T4, CraftPrefix.TAILORING,      {tuxedo=1, tailoring=1, tailor=1}},
		--[[tuxedo shirt            ]] {12085, false, Content.T4, CraftPrefix.TAILORING,      {tuxedo=1, tailoring=1, tailor=1}},
		-- Druid Tanking
		--[[heavy clefthoof vest    ]] {32495, false, Content.T4, CraftPrefix.LEATHERWORKING, {druid=1, tank=1, tanking=1, heavy=1, clefthoof=1, leatherworking=1, leather=1}},
		--[[heavy clefthoof leggings]] {32496, false, Content.T4, CraftPrefix.LEATHERWORKING, {druid=1, tank=1, tanking=1, heavy=1, clefthoof=1, leatherworking=1, leather=1}},
		--[[heavy clefthoof boots   ]] {32497, false, Content.T4, CraftPrefix.LEATHERWORKING, {druid=1, tank=1, tanking=1, heavy=1, clefthoof=1, leatherworking=1, leather=1}},
		--[[stylin purple hat       ]] {32485, false, Content.T4, CraftPrefix.LEATHERWORKING, {druid=1, tank=1, tanking=1, heavy=1, clefthoof=1, leatherworking=1, leather=1}},
	},
	----------------------------------------
	-- Alchemy
	----------------------------------------
	["ALCHEMY"] = { -- capatalized to not be a major keyword
		--[[Goblin Rocket Fuel           ]] {11456, false, Content.T4, CraftPrefix.ALCHEMY, {goblin=1, rocket=1, fuel=1}},
		--[[Mercurial Stone              ]] {38070, false, Content.T4, CraftPrefix.ALCHEMY, {mercurial=1, mer=1, merc=1, stone=1}},
		--[[Oil of Immolation            ]] {11451, false, Content.T4, CraftPrefix.ALCHEMY, {oil=1, immolation=1, immo=1}},
		--[[Transmute: Primal Life       ]] {29688, false, Content.T4, CraftPrefix.ALCHEMY, {transmute=1, primal=1, might=1}},
		--[[Transmute: Earthstorm Diamond]] {32765, false, Content.T4, CraftPrefix.ALCHEMY, {transmute=1, diamond=1, earthstorm=1}},
		--[[Transmute: Skyfire Diamond   ]] {32766, false, Content.T4, CraftPrefix.ALCHEMY, {transmute=1, diamond=1, skyfire=1}},

		-- Elixirs
		--[[Adept's Elixir                      ]] {33740, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, elixir=1, adept=1, spell=1, power=1, sp=1, damage=1, spelldamage=1, critical=1, spellcrit=1, ["24"]=1}},
		--[[Earthen Elixir                      ]] {39637, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, elixir=1, earthen=1, earth=1}},
		--[[Elixir of Camouflage                ]] {28543, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, elixir=1, camouflage=1, camo=1, track=1, tracking=1}},
		--[[Elixir of Demonslaying              ]] {11477, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, elixir=1, demonslaying=1, demon=1, slaying=1, slayer=1, slay=1}},
		--[[Elixir of Detect Lesser Invisibility]] { 3453, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, elixir=1, detect=1, lesser=1, invisibility=1, invis=1}},
		--[[Elixir of Detect Undead             ]] {11460, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, elixir=1, detect=1, undead=1, track=1}},
		--[[Elixir of Draenic Wisdom            ]] {39638, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, elixir=1, draenic=1, wisdom=1, intellect=1, spirit=1}},
		--[[Elixir of Dream Vision              ]] {11468, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, elixir=1, dream=1, vision=1}},
		--[[Elixir of Empowerment               ]] {28578, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, elixir=1, empowerment=1, empower=1, spell=1, penetration=1, spen=1, ["30"]=1}},
		--[[Elixir of Giant Growth              ]] { 8240, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, elixir=1, giant=1, growth=1}},
		--[[Elixir of Greater Water Breathing   ]] {22808, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, elixir=1, greater=1, water=1, breathing=1, breath=1, breathe=1, underwater=1}},
		--[[Elixir of Healing Power             ]] {28545, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, elixir=1, heal=1, power=1, bh=1}},
		--[[Elixir of Ironskin                  ]] {39639, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, elixir=1, iron=1, skin=1, ironskin=1, resilience=1, res=1, pvp=1, ["30"]=1}},
		--[[Elixir of Major Agility             ]] {28553, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, elixir=1, major=1, agility=1, critical=1, ["35"]=1}},
		--[[Elixir of Major Defense             ]] {28557, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, elixir=1, major=1, defense=1, armor=1, ["550"]=1}},
		--[[Elixir of Major Firepower           ]] {28556, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, elixir=1, major=1, fire=1, power=1, firepower=1, damage=1, spelldamage=1, ["55"]=1}},
		--[[Elixir of Major Fortitude           ]] {39636, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, elixir=1, major=1, fortitude=1, fort=1, health=1, hp5, ["250"]=1, ["10"]=1}},
		--[[Elixir of Major Frost Power         ]] {28549, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, elixir=1, major=1, frost=1, power=1, damage=1, spelldamage=1, ["55"]=1}},
		--[[Elixir of Major Mageblood           ]] {28570, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, elixir=1, major=1, mage=1, blood=1, mageblood=1, mp5=1, ["16"]=1}},
		--[[Elixir of Major Shadow Power        ]] {28558, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, elixir=1, major=1, shadow=1, power=1, damage=1, spelldamage=1, ["55"]=1}},
		--[[Elixir of Major Strength            ]] {28544, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, elixir=1, major=1, strength=1, ["35"]=1}},
		--[[Elixir of Mastery                   ]] {33741, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, elixir=1, mastery=1, stats=1, ["15"]=1}},
		--[[Elixir of the Searching Eye         ]] {28552, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, elixir=1, searching=1, eye=1, stealth=1, detection=1, detect=1}},
		--[[Elixir of Water Breathing           ]] { 7179, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, elixir=1, water=1, breathing=1, breath=1, breathe=1, underwater=1}},
		--[[Fel Strength Elixir                 ]] {38960, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, elixir=1, fel=1, strength=1, attack=1, power=1, ap=1, ["90"]=1}},
		--[[Gift of Arthas                      ]] {11466, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, elixir=1, gift=1, arthas=1, disease=1}},
		--[[Onslaught Elixir                    ]] {33738, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, elixir=1, onslaught=1, attack=1, power=1, ap=1, ["60"]=1}},
		-- Potions
		--[[Destruction Potion            ]] {28565, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, destruction=1, destro=1, dest=1, spell=1, critical=1, spellcrit=1, damage=1, spelldamage=1, power=1, sp=1}},
		--[[Fel Mana Potion               ]] {38961, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, fel=1, mana=1}},
		--[[Fel Regeneration Potion       ]] {38962, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, fel=1, regeneration=1, regen=1, reg=1}},
		--[[Free Action Potion            ]] { 6624, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, free=1, action=1, pvp=1}},
		--[[Haste Potion                  ]] {28564, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, haste=1}},
		--[[Heroic Potion                 ]] {28563, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, heroic=1, hero=1, strength=1}},
		--[[Insane Strength Potion        ]] {28550, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, insane=1, strength=1, defense=1, ["120"]=1, ["75"]=1}},
		--[[Invisibility Potion           ]] {11464, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, invisibility=1, invis=1}},
		--[[Ironshield Potion             ]] {28579, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, iron=1, shield=1, ironshield=1, armor=1}},
		--[[Lesser Invisibility Potion    ]] { 3448, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, lesser=1, invisibility=1, invis=1}},
		--[[Living Action Potion          ]] {24367, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, living=1, action=1, pvp=1, stun=1}},
		--[[Magic Resistance Potion       ]] {11453, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, magic=1, resistance=1, res=1, ["50"]=1}},
		--[[Major Arcane Protection Potion]] {28575, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, resistance=1, res=1, major=1, protection=1, arcane=1}},
		--[[Major Dreamless Sleep Potion  ]] {28562, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, major=1, dream=1, dreamless=1, sleep=1}},
		--[[Major Fire Protection Potion  ]] {28571, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, resistance=1, res=1, major=1, protection=1, fire=1}},
		--[[Major Frost Protection Potion ]] {28572, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, resistance=1, res=1, major=1, protection=1, frost=1}},
		--[[Major Healing Potion          ]] {17556, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, major=1, healing=1}},
		--[[Major Holy Protection Potion  ]] {28577, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, resistance=1, res=1, major=1, protection=1, holy=1}},
		--[[Major Mana Potion             ]] {17580, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, major=1, mana=1}},
		--[[Major Nature Protection Potion]] {28573, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, resistance=1, res=1, major=1, protection=1, nature=1}},
		--[[Major Shadow Protection Potion]] {28576, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, resistance=1, res=1, major=1, protection=1, shadow=1}},
		--[[Major Troll's Blood Potion    ]] {24368, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, major=1, troll=1, blood=1, hp5=1, ["20"]=1}},
		--[[Mighty Rage Potion            ]] {17552, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, mighty=1, rage=1, warrior=1}},
		--[[Purification Potion           ]] {17572, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, purification=1, purify=1, curse=1, disease=1, poison=1}},
		--[[Restoration Potion            ]] {11452, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, restorative=1, restore=1, restoration=1, dispel=1, curse=1, poison=1, disease=1}},
		--[[Shrouding Potion              ]] {28554, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, shrouding=1, shroud=1, threat=1}},
		--[[Sneaking Potion               ]] {28546, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, sneaking=1, sneak=1, stealth=1}},
		--[[Super Healing Potion          ]] {28551, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, super=1, heal=1, health=1}},
		--[[Super Mana Potion             ]] {28555, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, super=1, mana=1}},
		--[[Super Rejuvenation Potion     ]] {28586, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, super=1, rejuvenation=1, rej=1, rejuv=1, rejuve=1}},
		--[[Swiftness Potion              ]] { 2335, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, swiftness=1, swift=1, run=1, speed=1}},
		--[[Swim Speed Potion             ]] { 7841, false, Content.T4, CraftPrefix.ALCHEMY, {potion=1, swim=1, swimming=1, speed=1}},
		-- Flasks
		--[[Flask of Blinding Light    ]] {28590, false, Content.T4, CraftPrefix.ALCHEMY, {flask=1, blinding=1, light=1, spell=1, damage=1, spelldamage=1, arcane=1, holy=1, nature=1, ["80"]=1}},
		--[[Flask of Chromatic Wonder  ]] {42736, false, Content.T4, CraftPrefix.ALCHEMY, {flask=1, chromatic=1, resistance=1, res=1, ["25"]=1}},
		--[[Flask of Distilled Wisdom  ]] {17636, false, Content.T4, CraftPrefix.ALCHEMY, {flask=1, distilled=1, distill=1, distil=1, dist=1, wisdom=1, wis=1, intellect=1, ["65"]=1}},
		--[[Flask of Fortification     ]] {28587, false, Content.T4, CraftPrefix.ALCHEMY, {flask=1, fortification=1, fort=1, health=1, defense=1, tank=1, tanking=1, ["500"]=1, ["10"]=1}},
		--[[Flask of Mighty Restoration]] {28588, false, Content.T4, CraftPrefix.ALCHEMY, {flask=1, mighty=1, restoration=1, rest=1, restore=1, mana=1, regen=1, mp5=1, ["25"]=1}},
		--[[Flask of Petrification     ]] {17634, false, Content.T4, CraftPrefix.ALCHEMY, {flask=1, petrification=1, petri=1, petrify=1, petrifi=1, stone=1, invuln=1, invulnerable=1, invincible=1}},
		--[[Flask of Pure Death        ]] {28591, false, Content.T4, CraftPrefix.ALCHEMY, {flask=1, pure=1, death=1, spell=1, damage=1, spelldamage=1, shadow=1, fire=1, frost=1, ["80"]=1}},
		--[[Flask of Relentless Assault]] {28589, false, Content.T4, CraftPrefix.ALCHEMY, {flask=1, relentless=1, relent=1, assault=1, attack=1, power=1, ap=1, physical=1, ["120"]=1}},
		--[[Flask of Supreme Power     ]] {17637, false, Content.T4, CraftPrefix.ALCHEMY, {flask=1, supreme=1, power=1, magic=1, spell=1, sp=1, damage=1, spelldamage=1, ["70"]=1}},
		-- Cauldrons
		--[[Cauldron of Major Arcane Protection]] {41458, false, Content.T4, CraftPrefix.ALCHEMY, {cauldron=1, resistance=1, res=1, major=1, protection=1, arcane=1}},
		--[[Cauldron of Major Fire Protection  ]] {41500, false, Content.T4, CraftPrefix.ALCHEMY, {cauldron=1, resistance=1, res=1, major=1, protection=1, fire=1}},
		--[[Cauldron of Major Frost Protection ]] {41501, false, Content.T4, CraftPrefix.ALCHEMY, {cauldron=1, resistance=1, res=1, major=1, protection=1, frost=1}},
		--[[Cauldron of Major Nature Protection]] {41502, false, Content.T4, CraftPrefix.ALCHEMY, {cauldron=1, resistance=1, res=1, major=1, protection=1, nature=1}},
		--[[Cauldron of Major Shadow Protection]] {41503, false, Content.T4, CraftPrefix.ALCHEMY, {cauldron=1, resistance=1, res=1, major=1, protection=1, shadow=1}},
	},
	----------------------------------------
	-- Blacksmithing
	----------------------------------------
	["BLACKSMITHING"] = { -- capatalized to not be a major keyword
		--[[Adamantite Sharpening Stone]] {29656, false, Content.T4, CraftPrefix.BLACKSMITHING, {adamantite=1, stone=1, critical=1, damage=1, physical=1, sharpening=1, sharp=1, sharpen=1}},
		--[[Adamantite Weapon Chain    ]] {42688, false, Content.T4, CraftPrefix.BLACKSMITHING, {adamantite=1, weaponchain=1, chain=1, disarm=1, parry=1, ["15"]=1}},
		--[[Adamantite Weightstone     ]] {34608, false, Content.T4, CraftPrefix.BLACKSMITHING, {adamantite=1, stone=1, hit=1, physical=1, damage=1, weight=1, weightstone=1}},
		--[[Felsteel Shield Spike      ]] {29657, false, Content.T4, CraftPrefix.BLACKSMITHING, {felsteel=1, shield=1, spike=1}},
		--[[Greater Rune of Warding    ]] {32285, false, Content.T4, CraftPrefix.BLACKSMITHING, {greater=1, rune=1, ward=1, warding=1}},
		--[[Greater Ward of Shielding  ]] {29729, false, Content.T4, CraftPrefix.BLACKSMITHING, {greater=1, ward=1, shield=1, shielding=1}},
		--[[Mithril Spurs              ]] { 9964, false, Content.T4, CraftPrefix.BLACKSMITHING, {mithril=1, spurs=1, spur=1}},
		--[[Arcanite Skeleton Key      ]] {19669, false, Content.T4, CraftPrefix.BLACKSMITHING, {arcanite=1, skeleton=1, key=1}},
	},
	----------------------------------------
	-- Cooking
	----------------------------------------
	["food"] = {
		--[[Blackened Basilisk      ]] {33286, false, Content.T4, CraftPrefix.COOKING, {meat=1, black=1, blackened=1, basilisk=1, spell=1, damage=1, spelldamage=1, sp=1, ["23"]=1}},
		--[[Blackened Sporefish     ]] {33292, false, Content.T4, CraftPrefix.COOKING, {fish=1, black=1, blackened=1, spore=1, sporefish=1, mana=1, mp5=1, regen=1, stamina=1, health=1, ["20"]=1, ["8"]=1}},
		--[[Boiled Bloodfin         ]] {43761, false, Content.ZA, CraftPrefix.COOKING, {fish=1, boiled=1, bloodfin=1, resistance=1, res=1, ["8"]=1}},
		--[[Buzzard Bites           ]] --{33279, false, Content.T4, CraftPrefix.COOKING, {meat=1, buzzard=1, bites=1, stamina=1, health=1, ["20"]=1}},
		--[[Captain Rumsey's Lager  ]] {45695, false, Content.T4, CraftPrefix.COOKING, {captain=1, rumsey=1, lager=1, fishing=1, skill=1, profession=1, ["10"]=1}},
		--[[Clam Bar                ]] --{36210, false, Content.T4, CraftPrefix.COOKING, {meat=1, clam=1, bar=1, stamina=1, health=1, ["20"]=1}},
		--[[Crunchy Serpent         ]] {38868, false, Content.T4, CraftPrefix.COOKING, {meat=1, crunchy=1, serpent=1, spell=1, damage=1, spelldamage=1, sp=1, ["23"]=1}},
		--[[Delicious Chocolate Cake]] {43779, false, Content.ZA, CraftPrefix.COOKING, {delicious=1, chocolate=1, cake=1, happy=1, fireworks=1}},
		--[[Dragonbreath Chili      ]] {15906, false, Content.T4, CraftPrefix.COOKING, {dragon=1, breath=1, breathe=1, dragonbreath=1, chili=1, chilli=1, belch=1, flame=1, fire=1}},
		--[[Feltail Delight         ]] {33291, false, Content.T4, CraftPrefix.COOKING, {fish=1, feltail=1, delight=1, stamina=1, health=1, ["20"]=1}},
		--[[Fisherman's Feast       ]] {42302, false, Content.T4, CraftPrefix.COOKING, {fisher=1, fisherman=1, fishermans=1, feast=1}},
		--[[Golden Fish Sticks      ]] {33295, false, Content.T4, CraftPrefix.COOKING, {fish=1, gold=1, golden=1, fishstick=1, fishsticks=1, stick=1, sticks=1, heal=1, bh=1, ["44"]=1}},
		--[[Grilled Mudfish         ]] {33293, false, Content.T4, CraftPrefix.COOKING, {fish=1, grill=1, grilled=1, mudfish=1, agility=1, ["20"]=1}},
		--[[Hot Apple Cider         ]] {45022, false, Content.T4, CraftPrefix.COOKING, {hot=1, apple=1, cider=1, alcohol=1}},
		--[[Kibler's Bits           ]] {43772, false, Content.ZA, CraftPrefix.COOKING, {pet=1, kibler=1, kiblers=1, bits=1, bites=1}},
		--[[Mok'nathal Shortribs    ]] --{38867, false, Content.T4, CraftPrefix.COOKING, {meat=1, mok=1, nathal=1, shortrib=1, shortribs=1, stamina=1, health=1, ["20"]=1}},
		--[[Poached Bluefish        ]] {33294, false, Content.T4, CraftPrefix.COOKING, {fish=1, poached=1, bluefish=1, spell=1, damage=1, spelldamage=1, sp=1, ["23"]=1}},
		--[[Ravager Dog             ]] {33284, false, Content.T4, CraftPrefix.COOKING, {meat=1, ravager=1, dog=1, attack=1, power=1, ap=1, ["40"]=1}},
		--[[Roasted Clefthoof       ]] {33287, false, Content.T4, CraftPrefix.COOKING, {meat=1, roasted=1, clefthoof=1, strength=1, ["20"]=1}},
		--[[Savory Deviate Delight  ]] { 8238, false, Content.T4, CraftPrefix.COOKING, {savory=1, deviate=1, delight=1, pirate=1, ninja=1, shapeshift=1, costume=1}},
		--[[Skullfish Soup          ]] {43707, false, Content.ZA, CraftPrefix.COOKING, {fish=1, skullfish=1, soup=1, spell=1, critical=1, spellcrit=1, ["20"]=1}},
		--[[Spicy Crawdad           ]] {33296, false, Content.T4, CraftPrefix.COOKING, {fish=1, spicy=1, crawdad=1, stamina=1, health=1, ["30"]=1}},
		--[[Spicy Hot Talbuk        ]] {43765, false, Content.ZA, CraftPrefix.COOKING, {meat=1, spicy=1, hot=1, talbuk=1, hit=1, physical=1, ["20"]=1}},
		--[[Sporeling Snack         ]] {33285, false, Content.T4, CraftPrefix.COOKING, {pet=1, sporeling=1, snack=1}},
		--[[Stormchops              ]] {43758, false, Content.ZA, CraftPrefix.COOKING, {storm=1, chop=1, chops=1, stormchop=1, stormchops=1, lightning=1, shock=1}},
		--[[Talbuk Steak            ]] {33289, false, Content.T4, CraftPrefix.COOKING, {meat=1, talbuk=1, steak=1, stamina=1, health=1, ["20"]=1}},
		--[[Thistle Tea             ]] { 9513, false, Content.T4, CraftPrefix.COOKING, {thistle=1, tea=1, energy=1, rogue=1, rouge=1, ["40"]=1}},
		--[[Warp Burger             ]] {33288, false, Content.T4, CraftPrefix.COOKING, {meat=1, warp=1, burger=1, agility=1, ["20"]=1}},
	},
	----------------------------------------
	-- Enchanting / Enchantments
	----------------------------------------
	["ENCHANTING"] = { -- capatalized to not be a major keyword
		--[[Brilliant Mana Oil       ]] {25130, false, Content.T4, CraftPrefix.ENCHANTING, {brilliant=1, mana=1, oil=1, mp5=1, regen=1, heal=1, bh=1, ["14"]=1, ["25"]=1}},
		--[[Brilliant Wizard Oil     ]] {25129, false, Content.T4, CraftPrefix.ENCHANTING, {brilliant=1, wizard=1, oil=1, spell=1, damage=1, spelldamage=1, sp=1, critical=1, spellcrit=1, ["36"]=1, ["14"]=1}},
		--[[Large Prismatic Shard    ]] {28022, false, Content.T4, CraftPrefix.ENCHANTING, {large=1, prismatic=1, shard=1}},
		--[[Small Prismatic Shard    ]] {42615, false, Content.T4, CraftPrefix.ENCHANTING, {small=1, prismatic=1, shard=1}},
		--[[Superior Mana Oil        ]] {28016, false, Content.T4, CraftPrefix.ENCHANTING, {superior=1, mana=1, oil=1, mp5=1, regen=1, ["14"]=1}},
		--[[Superior Wizard Oil      ]] {28019, false, Content.T4, CraftPrefix.ENCHANTING, {superior=1, wizard=1, oil=1, spell=1, damage=1, spelldamage=1, sp=1, ["42"]=1}},
		--[[Void Shatter             ]] {45765, false, Content.SW, CraftPrefix.ENCHANTING, {void=1, shatter=1, crystal=1}},
	},

	["boots"] = {
		--[[Boar's Speed             ]] {34008, false, Content.T4, nil, {enchant=1, boar=1, speed=1, minor=1, movement=1, move=1, run=1, health=1, stamina=1, ["9"]=1}},
		--[[Cat's Swiftness          ]] {34007, false, Content.T4, nil, {enchant=1, cat=1, swift=1, swiftness=1, minor=1, movement=1, move=1, run=1, speed=1, agility=1, ["6"]=1}},
		--[[Dexterity                ]] {27951, false, Content.T4, nil, {enchant=1, dexterity=1, dex=1, dext=1, agility=1, ["12"]=1}},
		--[[Dexterity                ]] {27951, true,  Content.T4, nil, {dexterity=1}},
		--[[Fortitude                ]] {27950, false, Content.T4, nil, {enchant=1, fortitude=1, fort=1, stamina=1, health=1, ["12"]=1}},
		--[[Minor Speed              ]] {13890, false, Content.T4, nil, {enchant=1, minor=1, speed=1, movement=1, move=1, run=1}},
		--[[Spirit                   ]] {20024, false, Content.T4, nil, {enchant=1, spirit=1, ["5"]=1}},
		--[[Surefooted               ]] {27954, false, Content.T4, nil, {enchant=1, sure=1, footed=1, surefooted=1, snare=1, root=1, resistance=1, res=1, hit=1, physical=1, ["5"]=1, ["10"]=1}},
		--[[Surefooted               ]] {27954, true,  Content.T4, nil, {surefooted=1}},
		--[[Vitality                 ]] {27948, false, Content.T4, nil, {enchant=1, vitality=1, restore=1, mp5=1, hp5=1, regen=1, ["4"]=1, ["5"]=1}},
		--[[Vitality                 ]] {27948, true,  Content.T4, nil, {vitality=1}},
	},
	["bracer"] = {
		--[[Assault                  ]] {34002, false, Content.T4, nil, {enchant=1, assault=1, attack=1, power=1, ap=1, ["24"]=1}},
		--[[Brawn                    ]] {27899, false, Content.T4, nil, {enchant=1, brawn=1, strength=1, ["12"]=1}},
		--[[Deflection               ]] --{13931, false, Content.T4, nil, {enchant=1, deflection=1, deflect=1, defense=1, ["5"]=1}},
		--[[Deflection               ]] --{13931, true,  Content.T4, nil, {deflection=1}},
		--[[Fortitude                ]] {27914, false, Content.T4, nil, {enchant=1, fortitude=1, fort=1, stamina=1, health=1, ["12"]=1}},
		--[[Major Defense            ]] {27906, false, Content.T4, nil, {enchant=1, major=1, defense=1, ["12"]=1}},
		--[[Major Intellect          ]] {34001, false, Content.T4, nil, {enchant=1, major=1, intellect=1, ["12"]=1}},
		--[[Restore Mana Prime       ]] {27913, false, Content.T4, nil, {enchant=1, restore=1, mana=1, prime=1, mp5=1, regen=1, ["6"]=1}},
		--[[Spellpower               ]] {27917, false, Content.T4, nil, {enchant=1, spell=1, power=1, spellpower=1, sp=1, damage=1, spelldamage=1, ["15"]=1}},
		--[[Stats                    ]] {27905, false, Content.T4, nil, {enchant=1, stats=1, ["4"]=1}},
		--[[Superior Healing         ]] {27911, false, Content.T4, nil, {enchant=1, superior=1, heal=1, bh=1, ["30"]=1}},
		--[[Superior Spirit          ]] {20009, false, Content.T4, nil, {enchant=1, superior=1, spirit=1, ["9"]=1}},
	},
	["chest"] = {
		--[[Defense                  ]] {46594, false, Content.SW, nil, {enchant=1, defense=1, ["15"]=1}},
		--[[Exceptional Health       ]] {27957, false, Content.T4, nil, {enchant=1, exceptional=1, health=1, ["150"]=1}},
		--[[Exceptional Mana         ]] {27958, false, Content.T4, nil, {enchant=1, exceptional=1, mana=1, ["150"]=1}},
		--[[Exceptional Stats        ]] {27960, false, Content.T4, nil, {enchant=1, exceptional=1, stats=1, ["6"]=1}},
		--[[Major Resilience         ]] {33992, false, Content.T4, nil, {enchant=1, major=1, resilience=1, res=1, pvp=1, ["15"]=1}},
		--[[Major Spirit             ]] {33990, false, Content.T4, nil, {enchant=1, major=1, spirit=1, ["15"]=1}},
		--[[Restore Mana Prime       ]] {33991, false, Content.T4, nil, {enchant=1, restore=1, mana=1, prime=1, mp5=1, regen=1, ["6"]=1}},
	},
	["cloak"] = {
		--[[Dodge                    ]] {25086, false, Content.T4, nil, {enchant=1, dodge=1, ["12"]=1}},
		--[[Greater Agility          ]] {34004, false, Content.T4, nil, {enchant=1, greater=1, agility=1, ["12"]=1}},
		--[[Greater Arcane Resistance]] {34005, false, Content.T4, nil, {enchant=1, greater=1, arcane=1, resistance=1, res=1, ["15"]=1}},
		--[[Greater Fire Resistance  ]] {25081, false, Content.T4, nil, {enchant=1, greater=1, fire=1, resistance=1, res=1, ["15"]=1}},
		--[[Greater Nature Resistance]] {25082, false, Content.T4, nil, {enchant=1, greater=1, nature=1, resistance=1, res=1, ["15"]=1}},
		--[[Greater Shadow Resistance]] {34006, false, Content.T4, nil, {enchant=1, greater=1, shadow=1, resistance=1, res=1, ["15"]=1}},
		--[[Major Armor              ]] {27961, false, Content.T4, nil, {enchant=1, major=1, armor=1, ["120"]=1}},
		--[[Major Resistance         ]] {27962, false, Content.T4, nil, {enchant=1, major=1, resistance=1, res=1, magic=1, allres=1, ["7"]=1}},
		--[[Spell Penetration        ]] {34003, false, Content.T4, nil, {enchant=1, spell=1, penetration=1, sp=1, spen=1, ["20"]=1}},
		--[[Stealth                  ]] {25083, false, Content.T4, nil, {enchant=1, stealth=1}},
		--[[Steelweave               ]] {47051, false, Content.SW, nil, {enchant=1, steelweave=1, defense=1, ["12"]=1}},
		--[[Steelweave               ]] {47051, true,  Content.SW, nil, {steelweave=1}},
		--[[Subtlety                 ]] {25084, false, Content.T4, nil, {enchant=1, subtlety=1, sub=1, subtle=1, sublet=1, sublety=1, subtlely=1, threat=1, ["2"]=1}},
		--[[Subtlety                 ]] {25084, true,  Content.T4, nil, {subtlety=1, sublety=1, subtlely=1, threat=1}},
	},
	["gloves"] = {
		--[[Advanced Herbalism       ]] {13868, false, Content.T4, nil, {enchant=1, advanced=1, herbalism=1, herb=1, herbing=1, herbalist=1, skill=1, profession=1, ["5"]=1}},
		--[[Advanced Mining          ]] {13841, false, Content.T4, nil, {enchant=1, advanced=1, mining=1, miner=1, skill=1, profession=1, ["5"]=1}},
		--[[Assault                  ]] {33996, false, Content.T4, nil, {enchant=1, assault=1, attack=1, power=1, ap=1, ["26"]=1}},
		--[[Blasting                 ]] {33993, false, Content.T4, nil, {enchant=1, blasting=1, spell=1, critical=1, spellcrit=1, ["10"]=1}},
		--[[Fishing                  ]] {13620, false, Content.T4, nil, {enchant=1, fishing=1, fisn=1, skill=1, profession=1, ["2"]=1}},
		--[[Major Healing            ]] {33999, false, Content.T4, nil, {enchant=1, major=1, heal=1, bh=1, ["35"]=1}},
		--[[Major Spellpower         ]] {33997, false, Content.T4, nil, {enchant=1, major=1, spell=1, power=1, spellpower=1, sp=1, damage=1, spelldamage=1, ["20"]=1}},
		--[[Major Strength           ]] {33995, false, Content.T4, nil, {enchant=1, major=1, strength=1, ["15"]=1}},
		--[[Minor Haste              ]] {13948, false, Content.T4, nil, {enchant=1, minor=1, haste=1, ["10"]=1}},
		--[[Riding Skill             ]] {13947, false, Content.T4, nil, {enchant=1, riding=1, skill=1, mount=1, speed=1, ["2"]=1}},
		--[[Skinning                 ]] {13698, false, Content.T4, nil, {enchant=1, skinning=1, skin=1, skinner=1, skill=1, profession=1, ["5"]=1}},
		--[[Spell Strike             ]] {33994, false, Content.T4, nil, {enchant=1, spell=1, strike=1, spellstrike=1, hit=1, spellhit=1, ["15"]=1}},
		--[[Superior Agility         ]] {25080, false, Content.T4, nil, {enchant=1, superior=1, agility=1, ["15"]=1}},
		--[[Threat                   ]] {25072, false, Content.T4, nil, {enchant=1, threat=1, ["2"]=1}},
		--[[Threat                   ]] {25072, true,  Content.T4, nil, {threat=1}},
	},
	["legs"] = {
		--[[Clefthide Leg Armor      ]] {35555, false, Content.T4, CraftPrefix.LEATHERWORKING, {enchant=1, leatherworker=1, leatherworking=1, legarmor=1, rare=1, blue=1, cleft=1, clefthide=1, stamina=1, health=1, tank=1, tanking=1, agility=10, ["30"]=1, ["10"]=1}},
		--[[Cobrahide Leg Armor      ]] {35549, false, Content.T4, CraftPrefix.LEATHERWORKING, {enchant=1, leatherworker=1, leatherworking=1, legarmor=1, rare=1, blue=1, cobra=1, hide=1, cobrahide=1, attack=1, power=1, ap=1, critical=1, dps=1, physical=1, ["40"]=1, ["10"]=1}},
		--[[Golden Spellthread       ]] {31433, false, Content.T4, CraftPrefix.TAILORING,      {enchant=1, tailor=1, tailoring=1, epic=1, purple=1, gold=1, golden=1, spellthread=1, thread=1, spell=1, heal=1, bh=1, ["66"]=1}},
		--[[Mystic Spellthread       ]] {31430, false, Content.T4, CraftPrefix.TAILORING,      {enchant=1, tailor=1, tailoring=1, rare=1, blue=1, mystic=1, spellthread=1, thread=1, spell=1, power=1, sp=1, damage=1, spelldamage=1, dps=1, ["25"]=1}},
		--[[Nethercleft Leg Armor    ]] {35557, false, Content.T4, CraftPrefix.LEATHERWORKING, {enchant=1, leatherworker=1, leatherworking=1, legarmor=1, epic=1, purple=1, nether=1, nethercleft=1, stamina=1, health=1, tank=1, tanking=1, agility=1, ["40"]=1, ["12"]=1}},
		--[[Nethercobra Leg Armor    ]] {35554, false, Content.T4, CraftPrefix.LEATHERWORKING, {enchant=1, leatherworker=1, leatherworking=1, legarmor=1, epic=1, purple=1, nether=1, cobra=1, nethercobra=1, attack=1, power=1, ap=1, critical=1, dps=1, physical=1, ["40"]=1, ["10"]=1}},
		--[[Runic Spellthread        ]] {31432, false, Content.T4, CraftPrefix.TAILORING,      {enchant=1, tailor=1, tailoring=1, epic=1, purple=1, runic=1, spellthread=1, thread=1, spell=1, power=1, sp=1, damage=1, spelldamage=1, dps=1, ["35"]=1}},
		--[[Silver Spellthread       ]] {31431, false, Content.T4, CraftPrefix.TAILORING,      {enchant=1, tailor=1, tailoring=1, rare=1, blue=1, silver=1, spellthread=1, thread=1, spell=1, heal=1, bh=1, ["46"]=1}},
	},
	["RING"] = { -- capatalized to not be a major keyword
		--[[Healing Power            ]] {27926, false, Content.T4, nil, {enchant=1, ring=1, heal=1, bh=1, power=1, ["20"]=1}},
		--[[Spellpower               ]] {27924, false, Content.T4, nil, {enchant=1, ring=1, spell=1, power=1, spellpower=1, sp=1, damage=1, spelldamage=1, ["12"]=1}},
		--[[Stats                    ]] {27927, false, Content.T4, nil, {enchant=1, ring=1, stats=1, ["4"]=1}},
		--[[Striking                 ]] {27920, false, Content.T4, nil, {enchant=1, ring=1, striking=1, damage=1, physical=1, weapondamage=1, ["2"]=1}},
	},
	["SHIELD"] = { -- capatalized to not be a major keyword
		--[[Intellect                ]] {27945, false, Content.T4, nil, {enchant=1, shield=1, intellect=1, ["12"]=1}},
		--[[Major Stamina            ]] {34009, false, Content.T4, nil, {enchant=1, shield=1, major=1, stamina=1, health=1, ["18"]=1}},
		--[[Resilience               ]] {44383, false, Content.T4, nil, {enchant=1, shield=1, resilience=1, res=1, pvp=1, ["12"]=1}},
		--[[Resistance               ]] {27947, false, Content.T4, nil, {enchant=1, shield=1, resistance=1, res=1, magic=1, ["5"]=1}},
		--[[Shield Block             ]] {27946, false, Content.T4, nil, {enchant=1, shield=1, block=1, ["15"]=1}},
		--[[Tough Shield             ]] {27944, false, Content.T4, nil, {enchant=1, shield=1, tough=1, block=1, value=1, ["18"]=1}},
	},
	["weapon"] = {
		--[[2H: Major Agility        ]] {27977, false, Content.T4, nil, {enchant=1, ["2h"]=1, two=1, ["2"]=1, handed=1, major=1, agility=1, ["35"]=1}},
		--[[2H: Savagery             ]] {27971, false, Content.T4, nil, {enchant=1, ["2h"]=1, two=1, ["2"]=1, handed=1, savagery=1, savage=1, sav=1, attack=1, power=1, ap=1, ["70"]=1}},
		--[[2H: Savagery             ]] {27971, true,  Content.T4, nil, {savagery=1}},
		--[[2H: Superior Impact      ]] {20030, false, Content.T4, nil, {enchant=1, ["2h"]=1, two=1, ["2"]=1, handed=1, superior=1, impact=1, damage=1, physical=1, weapondamage=1, ["9"]=1}},
		--[[Battlemaster             ]] {28004, false, Content.T4, nil, {enchant=1, ["1h"]=1, one=1, ["1"]=1, handed=1, battle=1, master=1, battlemaster=1, ["180"]=1, ["300"]=1}},
		--[[Battlemaster             ]] {28004, true,  Content.T4, nil, {battlemaster=1}},
		--[[Crusader                 ]] {20034, false, Content.T4, nil, {enchant=1, ["1h"]=1, one=1, ["1"]=1, handed=1, crusader=1, crusade=1, strength=1, ["100"]=1}},
		--[[Crusader                 ]] {20034, true,  Content.T4, nil, {crusader=1}},
		--[[Deathfrost               ]] {46578, false, Content.T4, nil, {enchant=1, ["1h"]=1, one=1, ["1"]=1, handed=1, death=1, frost=1, deathfrost=1, ["150"]=1, slow=1}},
		--[[Deathfrost               ]] {46578, true,  Content.T4, nil, {deathfrost=1}},
		--[[Demonslaying             ]] {13915, false, Content.T4, nil, {enchant=1, ["1h"]=1, one=1, ["1"]=1, handed=1, demon=1, slaying=1, slay=1, slayer=1, demonslaying=1, demonslay=1, demonslayer=1}},
		--[[Executioner              ]] {42974, false, Content.ZA, nil, {enchant=1, ["1h"]=1, one=1, ["1"]=1, handed=1, executioner=1, exe=1, exec=1, execution=1, execute=1, ignore=1, armor=1, penetration=1, arpen=1, ["840"]=1}},
		--[[Executioner              ]] {42974, true,  Content.ZA, nil, {executioner=1}},
		--[[Fiery Weapon             ]] {13898, false, Content.T4, nil, {enchant=1, ["1h"]=1, one=1, ["1"]=1, handed=1, fiery=1, feiry=1, firey=1, fire=1, damage=1}},
		--[[Greater Agility          ]] {42620, false, Content.T4, nil, {enchant=1, ["1h"]=1, one=1, ["1"]=1, handed=1, greater=1, agility=1, ["20"]=1}},
		--[[Icy Chill                ]] {20029, false, Content.T4, nil, {enchant=1, ["1h"]=1, one=1, ["1"]=1, handed=1, icy=1, chill=1, slow=1}},
		--[[Lesser Beastslayer       ]] {13653, false, Content.T4, nil, {enchant=1, ["1h"]=1, one=1, ["1"]=1, handed=1, lesser=1, beast=1, slayer=1, slay=1, slaying=1, beastslayer=1, beastslay=1, beastslaying=1}},
		--[[Lesser Elemenal Slayer   ]] {13655, false, Content.T4, nil, {enchant=1, ["1h"]=1, one=1, ["1"]=1, handed=1, lesser=1, elemental=1, slayer=1, slay=1, slaying=1, element=1}},
		--[[Lifestealing             ]] {20032, false, Content.T4, nil, {enchant=1, ["1h"]=1, one=1, ["1"]=1, handed=1, life=1, steal=1, stealing=1, lifesteal=1, lifestealing=1}},
		--[[Major Healing            ]] {34010, false, Content.T4, nil, {enchant=1, ["1h"]=1, one=1, ["1"]=1, handed=1, major=1, heal=1, bh=1, ["81"]=1}},
		--[[Major Intellect          ]] {27968, false, Content.T4, nil, {enchant=1, ["1h"]=1, one=1, ["1"]=1, handed=1, major=1, intellect=1, ["30"]=1}},
		--[[Major Spellpower         ]] {27975, false, Content.T4, nil, {enchant=1, ["1h"]=1, one=1, ["1"]=1, handed=1, major=1, spell=1, power=1, spellpower=1, sp=1, damage=1, spelldamage=1, ["40"]=1}},
		--[[Major Striking           ]] {27967, false, Content.T4, nil, {enchant=1, ["1h"]=1, one=1, ["1"]=1, handed=1, weapondamage=1, physical=1, major=1, striking=1, damage=1, ["7"]=1}},
		--[[Mighty Spirit            ]] {23803, false, Content.T4, nil, {enchant=1, ["1h"]=1, one=1, ["1"]=1, handed=1, mighty=1, spirit=1, ["20"]=1}},
		--[[Mongoose                 ]] {27984, false, Content.T4, nil, {enchant=1, ["1h"]=1, one=1, ["1"]=1, handed=1, mongoose=1}},
		--[[Mongoose                 ]] {27984, true,  Content.T4, nil, {mongoose=1}},
		--[[Potency                  ]] {27972, false, Content.T4, nil, {enchant=1, ["1h"]=1, one=1, ["1"]=1, handed=1, potency=1, potent=1, strength=1, ["20"]=1}},
		--[[Potency                  ]] {27972, true,  Content.T4, nil, {potency=1}},
		--[[Soulfrost                ]] {27982, false, Content.T4, nil, {enchant=1, ["1h"]=1, one=1, ["1"]=1, handed=1, soul=1, frost=1, soulfrost=1, ["54"]=1}},
		--[[Soulfrost                ]] {27982, true,  Content.T4, nil, {soulfrost=1}},
		--[[Spellsurge               ]] {28003, false, Content.T4, nil, {enchant=1, ["1h"]=1, one=1, ["1"]=1, handed=1, spell=1, surge=1, spellsurge=1, restore=1, mana=1, ["100"]=1}},
		--[[Spellsurge               ]] {28003, true,  Content.T4, nil, {spellsurge=1}},
		--[[Sunfire                  ]] {27981, false, Content.T4, nil, {enchant=1, ["1h"]=1, one=1, ["1"]=1, handed=1, sun=1, fire=1, sunfire=1, ["50"]=1}},
		--[[Sunfire                  ]] {27981, true,  Content.T4, nil, {sunfire=1}},
		--[[Unholy Weapon            ]] {20033, false, Content.T4, nil, {enchant=1, ["1h"]=1, one=1, ["1"]=1, handed=1, unholy=1, curse=1}},
	},
	----------------------------------------
	-- Jewelcrafting
	----------------------------------------
	["JEWELCRAFTING"] = { -- capatalized to not be a major keyword
		--[[Mercurial Adamantite        ]] {38068, false, Content.T4, CraftPrefix.JEWELCRAFTING, {mercurial=1, merc=1, adamantite=1}},
		--[[Necklace of the Deep        ]] {40514, false, Content.T4, CraftPrefix.JEWELCRAFTING, {necklace=1, neck=1, deep=1}},
		--[[The Frozen Eye              ]] {38503, false, Content.T4, CraftPrefix.JEWELCRAFTING, {ring=1, resistance=1, res=1, ["35"]=1, frost=1, frozen=1, eye=1}},
		--[[The Natural Ward            ]] {38504, false, Content.T4, CraftPrefix.JEWELCRAFTING, {ring=1, resistance=1, res=1, ["35"]=1, nature=1, natural=1, ward=1}},
		--[[Figurine Shadowsong Panther ]] {46778, false, Content.T4, CraftPrefix.JEWELCRAFTING, {figurine=1, figure=1, shadowsong=1, panther=1}},
		--[[Figurine Seaspray Albatross ]] {46779, false, Content.T4, CraftPrefix.JEWELCRAFTING, {figurine=1, figure=1, seaspray=1, albatross=1}},
		--[[Figurine Khorium Boar       ]] {46776, false, Content.T4, CraftPrefix.JEWELCRAFTING, {figurine=1, figure=1, khorium=1, boar=1}},
		--[[Figurine Empyrean Tortoise  ]] {46775, false, Content.T4, CraftPrefix.JEWELCRAFTING, {figurine=1, figure=1, empyrean=1, tortoise=1}},
		--[[Figurine Crimson Serpent    ]] {46777, false, Content.T4, CraftPrefix.JEWELCRAFTING, {figurine=1, figure=1, crimson=1, serpent=1}},
		--[[Figurine Talasite Owl       ]] {31082, false, Content.T4, CraftPrefix.JEWELCRAFTING, {figurine=1, figure=1, talasite=1, owl=1}},
		--[[Figurine Nightseye Panther  ]] {31083, false, Content.T4, CraftPrefix.JEWELCRAFTING, {figurine=1, figure=1, nightseye=1, panther=1}},
		--[[Figurine Living Ruby Serpent]] {31081, false, Content.T4, CraftPrefix.JEWELCRAFTING, {figurine=1, figure=1, living=1, ruby=1, serpent=1}},
		--[[Figurine Felsteel Boar      ]] {31079, false, Content.T4, CraftPrefix.JEWELCRAFTING, {figurine=1, figure=1, felsteel=1, boar=1}},
		--[[Figurine Dawnstone Crab     ]] {31080, false, Content.T4, CraftPrefix.JEWELCRAFTING, {figurine=1, figure=1, dawnstone=1, crab=1}},

		--[[Ring Of Arcane Shielding    ]] {37855, false, Content.T4, CraftPrefix.JEWELCRAFTING, {ring=1, resistance=1, res=1, ["30"]=1, arcane=1, shielding=1}},
		--[[Fendant of Withering        ]] {31064, false, Content.T4, CraftPrefix.JEWELCRAFTING, {pendant=1, necklace=1, resistance=1, res=1, ["30"]=1, nature=1, withering=1}},
		--[[Pendant of the Null Rune    ]] {31066, false, Content.T4, CraftPrefix.JEWELCRAFTING, {pendant=1, necklace=1, resistance=1, res=1, ["30"]=1, arcane=1, null=1, rune=1}},
		--[[Pendant of Thawing          ]] {31063, false, Content.T4, CraftPrefix.JEWELCRAFTING, {pendant=1, necklace=1, resistance=1, res=1, ["30"]=1, frost=1, thawing=1}},
		--[[Pendant of Shadows End      ]] {31065, false, Content.T4, CraftPrefix.JEWELCRAFTING, {pendant=1, necklace=1, resistance=1, res=1, ["30"]=1, shadow=1, shadows=1, ["end"]=1}},
		--[[Pendant of Frozen Flame     ]] {31062, false, Content.T4, CraftPrefix.JEWELCRAFTING, {pendant=1, necklace=1, resistance=1, res=1, ["30"]=1, fire=1, frozen=1, flame=1}},
	},
	["gem"] = {
		-- Rare
		--[[Balanced Nightseye     ]] {39463, false, Content.T4, CraftPrefix.JEWELCRAFTING, {nometa=1, rare=1, purple=1, red=1, blue=1, balanced=1, nightseye=1, attack=1, power=1, ap=1, stamina=1, ["8"]=1, ["6"]=1}},
		--[[Bold Living Ruby       ]] {31084, false, Content.T4, CraftPrefix.JEWELCRAFTING, {nometa=1, rare=1, pure=1, red=1, bold=1, living=1, ruby=1, strength=1, ["8"]=1}},
		--[[Bright Living Ruby     ]] {31089, false, Content.T4, CraftPrefix.JEWELCRAFTING, {nometa=1, rare=1, pure=1, red=1, bright=1, living=1, ruby=1, attack=1, power=1, ap=1, ["16"]=1}},
		--[[Brilliant Dawnstone    ]] {31096, false, Content.T4, CraftPrefix.JEWELCRAFTING, {nometa=1, rare=1, pure=1, yellow=1, brilliant=1, dawnstone=1, intellect=1, ["8"]=1}},
		--[[Dazzling Talasite      ]] {31112, false, Content.T4, CraftPrefix.JEWELCRAFTING, {nometa=1, rare=1, green=1, yellow=1, blue=1, dazzling=1, talasite=1, intellect=1, mana=1, mp5=1, regen=1, ["4"]=1, ["2"]=1}},
		--[[Delicate Living Ruby   ]] {31085, false, Content.T4, CraftPrefix.JEWELCRAFTING, {nometa=1, rare=1, pure=1, red=1, delicate=1, living=1, ruby=1, agility=1, ["8"]=1}},
		--[[Enduring Talasite      ]] {31110, false, Content.T4, CraftPrefix.JEWELCRAFTING, {nometa=1, rare=1, green=1, yellow=1, blue=1, enduring=1, talasite=1, defense=1, stamina=1, ["4"]=1, ["6"]=1}},
		--[[Flashing Living Ruby   ]] {31091, false, Content.T4, CraftPrefix.JEWELCRAFTING, {nometa=1, rare=1, pure=1, red=1, flashing=1, living=1, ruby=1, parry=1, ["8"]=1}},
		--[[Forceful Talasite      ]] {46405, false, Content.SW, CraftPrefix.JEWELCRAFTING, {nometa=1, rare=1, green=1, yellow=1, blue=1, forceful=1, talasite=1, spell=1, haste=1, stamina=1, ["4"]=1, ["6"]=1}},
		--[[Gleaming Dawnstone     ]] {31099, false, Content.T4, CraftPrefix.JEWELCRAFTING, {nometa=1, rare=1, pure=1, yellow=1, gleaming=1, dawnstone=1, spell=1, critical=1, spellcrit=1, ["8"]=1}},
		--[[Glinting Noble Topaz   ]] {31109, false, Content.T4, CraftPrefix.JEWELCRAFTING, {nometa=1, rare=1, orange=1, red=1, yellow=1, glinting=1, noble=1, topaz=1, hit=1, physical=1, agility=1, ["4"]=1}},
		--[[Glowing Nightseye      ]] {31104, false, Content.T4, CraftPrefix.JEWELCRAFTING, {nometa=1, rare=1, purple=1, red=1, blue=1, glowing=1, nightseye=1, spell=1, damage=1, spelldamage=1, sp=1, stamina=1, ["5"]=1, ["6"]=1}},
		--[[Great Dawnstone        ]] {39452, false, Content.T4, CraftPrefix.JEWELCRAFTING, {nometa=1, rare=1, pure=1, yellow=1, great=1, dawnstone=1, spell=1, hit=1, spellhit=1, ["8"]=1}},
		--[[Infused Nightseye      ]] {39462, false, Content.T4, CraftPrefix.JEWELCRAFTING, {nometa=1, rare=1, purple=1, red=1, blue=1, infused=1, nightseye=1, attack=1, power=1, ap=1, mana=1, mp5=1, regen=1, ["8"]=1, ["2"]=1}},
		--[[Inscribed Noble Topaz  ]] {31106, false, Content.T4, CraftPrefix.JEWELCRAFTING, {nometa=1, rare=1, orange=1, red=1, yellow=1, inscribed=1, noble=1, topaz=1, critical=1, physical=1, strength=1, ["4"]=1}},
		--[[Jagged Talasite        ]] {31113, false, Content.T4, CraftPrefix.JEWELCRAFTING, {nometa=1, rare=1, green=1, yellow=1, blue=1, jagged=1, talasite=1, critical=1, physical=1, stamina=1, ["4"]=1, ["6"]=1}},
		--[[Luminous Noble Topaz   ]] {31108, false, Content.T4, CraftPrefix.JEWELCRAFTING, {nometa=1, rare=1, orange=1, red=1, yellow=1, luminous=1, noble=1, topaz=1, heal=1, intellect=1, ["9"]=1, ["4"]=1}},
		--[[Lustrous Star of Elune ]] {31094, false, Content.T4, CraftPrefix.JEWELCRAFTING, {nometa=1, rare=1, pure=1, blue=1, lustrous=1, star=1, elune=1, mana=1, mp5=1, regen=1, ["3"]=1}},
		--[[Mystic Dawnstone       ]] {31101, false, Content.T4, CraftPrefix.JEWELCRAFTING, {nometa=1, rare=1, pure=1, yellow=1, mystic=1, dawnstone=1, resilience=1, res=1, pvp=1, ["8"]=1}},
		--[[Potent Noble Topaz     ]] {31107, false, Content.T4, CraftPrefix.JEWELCRAFTING, {nometa=1, rare=1, orange=1, red=1, yellow=1, potent=1, noble=1, topaz=1, spell=1, critical=1, spellcrit=1, damage=1, spelldamage=1, sp=1, ["4"]=1, ["5"]=1}},
		--[[Prismatic Sphere       ]] {28027, false, Content.T4, CraftPrefix.ENCHANTING,    {nometa=1, rare=1, prismatic=1, sphere=1, resistance=1, res=1, ["3"]=1}},
		--[[Purified Shadow Pearl  ]] {41429, false, Content.T4, CraftPrefix.JEWELCRAFTING, {nometa=1, rare=1, purple=1, red=1, blue=1, purified=1, shadow=1, pearl=1, heal=1, spirit=1, ["9"]=1, ["4"]=1}},
		--[[Quick Dawnstone        ]] {46403, false, Content.SW, CraftPrefix.JEWELCRAFTING, {nometa=1, rare=1, pure=1, yellow=1, quick=1, dawnstone=1, spell=1, haste=1, ["8"]=1}},
		--[[Radiant Talasite       ]] {31111, false, Content.T4, CraftPrefix.JEWELCRAFTING, {nometa=1, rare=1, green=1, yellow=1, blue=1, radiant=1, talasite=1, spell=1, critical=1, spellcrit=1, penetration=1, spen=1, ["4"]=1, ["5"]=1}},
		--[[Reckless Noble Topaz   ]] {46404, false, Content.SW, CraftPrefix.JEWELCRAFTING, {nometa=1, rare=1, orange=1, red=1, yellow=1, reckless=1, noble=1, topaz=1, spell=1, haste=1, damage=1, spelldamage=1, sp=1, ["4"]=1, ["5"]=1}},
		--[[Regal Nightseye        ]] {46803, false, Content.SW, CraftPrefix.JEWELCRAFTING, {nometa=1, rare=1, purple=1, red=1, blue=1, regal=1, nightseye=1, dodge=1, stamina=1, ["4"]=1, ["6"]=1}},
		--[[Rigid Dawnstone        ]] {31098, false, Content.T4, CraftPrefix.JEWELCRAFTING, {nometa=1, rare=1, pure=1, yellow=1, rigid=1, dawnstone=1, hit=1, physical=1, [8]=1}},
		--[[Royal Nightseye        ]] {31105, false, Content.T4, CraftPrefix.JEWELCRAFTING, {nometa=1, rare=1, purple=1, red=1, blue=1, royal=1, nightseye=1, heal=1, mana=1, mp5=1, regen=1, ["9"]=1, ["2"]=1}},
		--[[Runed Living Ruby      ]] {31088, false, Content.T4, CraftPrefix.JEWELCRAFTING, {nometa=1, rare=1, pure=1, red=1, runed=1, living=1, ruby=1, spell=1, damage=1, spelldamage=1, sp=1, ["9"]=1}},
		--[[Shifting Nightseye     ]] {31103, false, Content.T4, CraftPrefix.JEWELCRAFTING, {nometa=1, rare=1, purple=1, red=1, blue=1, shifting=1, nightseye=1, agility=1, stamina=1, ["4"]=1, ["6"]=1}},
		--[[Smooth Dawnstone       ]] {31097, false, Content.T4, CraftPrefix.JEWELCRAFTING, {nometa=1, rare=1, pure=1, yellow=1, smooth=1, dawnstone=1, critical=1, physical=1, ["8"]=1}},
		--[[Solid Star of Elune    ]] {31092, false, Content.T4, CraftPrefix.JEWELCRAFTING, {nometa=1, rare=1, pure=1, blue=1, solid=1, star=1, elune=1, stamina=1, onlystamina=1, ["12"]=1}},
		--[[Sovereign Nightseye    ]] {31102, false, Content.T4, CraftPrefix.JEWELCRAFTING, {nometa=1, rare=1, purple=1, red=1, blue=1, sovereign=1, nightseye=1, strength=1, stamina=1, ["4"]=1, ["6"]=1}},
		--[[Sparkling Star of Elune]] {31149, false, Content.T4, CraftPrefix.JEWELCRAFTING, {nometa=1, rare=1, pure=1, blue=1, sparkling=1, star=1, elune=1, spiri=1, ["8"]=1}},
		--[[Steady Talasite        ]] {43493, false, Content.T4, CraftPrefix.JEWELCRAFTING, {nometa=1, rare=1, green=1, yellow=1, blue=1, steady=1, talasite=1, resilience=1, res=1, pvp=1, stamina=1, ["4"]=1, ["6"]=1}},
		--[[Stormy Star of Elune   ]] {31095, false, Content.T4, CraftPrefix.JEWELCRAFTING, {nometa=1, rare=1, pure=1, blue=1, stormy=1, star=1, elune=1, spell=1, penetration=1, spen=1, ["10"]=1}},
		--[[Subtle Living Ruby     ]] {31090, false, Content.T4, CraftPrefix.JEWELCRAFTING, {nometa=1, rare=1, pure=1, red=1, subtle=1, living=1, ruby=1, dodge=1, ["8"]=1}},
		--[[Teardrop Living Ruby   ]] {31087, false, Content.T4, CraftPrefix.JEWELCRAFTING, {nometa=1, rare=1, pure=1, red=1, teardrop=1, living=1, ruby=1, heal=1, bh=1, ["18"]=1}},
		--[[Thick Dawnstone        ]] {31100, false, Content.T4, CraftPrefix.JEWELCRAFTING, {nometa=1, rare=1, pure=1, yellow=1, thick=1, dawnstone=1, defense=1, ["8"]=1}},
		--[[Veiled Noble Topaz     ]] {39470, false, Content.T4, CraftPrefix.JEWELCRAFTING, {nometa=1, rare=1, orange=1, red=1, yellow=1, veiled=1, noble=1, topaz=1, spell=1, hit=1, spellhit=1, damage=1, spelldamage=1, sp=1, ["4"]=1, ["5"]=1}},
		--[[Wicked Noble Topaz     ]] {39471, false, Content.T4, CraftPrefix.JEWELCRAFTING, {nometa=1, rare=1, orange=1, red=1, yellow=1, wicked=1, noble=1, topaz=1, critical=1, attack=1, power=1, ap=1, physical=1, ["4"]=1, ["8"]=1}},
		-- Epic
		--[[Balanced Shadowsong Amethyst ]] {39729, false, Content.T6, CraftPrefix.JEWELCRAFTING, {nometa=1, epic=1, purple=1, red=1, blue=1, balanced=1, shadowsong=1, amethyst=1, attack=1, power=1, ap=1, stamina=1, ["10"]=1, ["7"]=1}},
		--[[Bold Crimson Spinel          ]] {39705, false, Content.T6, CraftPrefix.JEWELCRAFTING, {nometa=1, epic=1, pure=1, red=1, bold=1, crimson=1, spinel=1, strength=1, ["10"]=1}},
		--[[Bright Crimson Spinel        ]] {39712, false, Content.T6, CraftPrefix.JEWELCRAFTING, {nometa=1, epic=1, pure=1, red=1, bright=1, crimson=1, spinel=1, attack=1, power=1, ap=1, ["20"]=1}},
		--[[Brilliant Lionseye           ]] {39719, false, Content.T6, CraftPrefix.JEWELCRAFTING, {nometa=1, epic=1, pure=1, yellow=1, brilliant=1, lionseye=1, intellect=1, ["10"]=1}},
		--[[Dazzling Seaspray Emerald    ]] {39741, false, Content.T6, CraftPrefix.JEWELCRAFTING, {nometa=1, epic=1, green=1, dazzling=1, seaspray=1, emerald=1, intellect=1, mana=1, mp5=1, regen=1, ["5"]=1, ["2"]=1}},
		--[[Delicate Crimson Spinel      ]] {39706, false, Content.T6, CraftPrefix.JEWELCRAFTING, {nometa=1, epic=1, pure=1, red=1, delicate=1, crimson=1, spinel=1, agility=1, ["10"]=1}},
		--[[Enduring Seaspray Emerald    ]] {39739, false, Content.T6, CraftPrefix.JEWELCRAFTING, {nometa=1, epic=1, green=1, enduring=1, seaspray=1, emerald=1, defense=1, stamina=1, ["5"]=1, ["7"]=1}},
		--[[Flashing Crimson Spinel      ]] {39714, false, Content.T6, CraftPrefix.JEWELCRAFTING, {nometa=1, epic=1, pure=1, red=1, flashing=1, crimson=1, spinel=1, parry=1, ["10"]=1}},
		--[[Forceful Seaspray Emerald    ]] {47053, false, Content.SW, CraftPrefix.JEWELCRAFTING, {nometa=1, epic=1, green=1, forceful=1, seaspray=1, emerald=1, spell=1, haste=1, stamina=1, ["5"]=1, ["7"]=1}},
		--[[Gleaming Lionseye            ]] {39722, false, Content.T6, CraftPrefix.JEWELCRAFTING, {nometa=1, epic=1, pure=1, yellow=1, gleaming=1, lionseye=1, spell=1, critical=1, spellcrit=1, ["10"]=1}},
		--[[Glinting Pyrestone           ]] {39736, false, Content.T6, CraftPrefix.JEWELCRAFTING, {nometa=1, epic=1, orange=1, red=1, yellow=1, glinting=1, pyrestone=1, hit=1, physical=1, agility=1, ["5"]=1}},
		--[[Glowing Shadowsong Amethyst  ]] {39731, false, Content.T6, CraftPrefix.JEWELCRAFTING, {nometa=1, epic=1, purple=1, red=1, blue=1, glowing=1, shadowsong=1, amethyst=1, spell=1, damage=1, spelldamage=1, sp=1, stamina=1, ["6"]=1, ["7"]=1}},
		--[[Great Lionseye               ]] {39725, false, Content.T6, CraftPrefix.JEWELCRAFTING, {nometa=1, epic=1, pure=1, yellow=1, great=1, lionseye=1, spell=1, hit=1, spellhit=1, ["10"]=1}},
		--[[Infused Shadowsong Amethyst  ]] {39730, false, Content.T6, CraftPrefix.JEWELCRAFTING, {nometa=1, epic=1, purple=1, red=1, blue=1, infused=1, shadowsong=1, amethyst=1, attack=1, power=1, ap=1, mana=1, mp5=1, regen=1, ["10"]=1, ["2"]=1}},
		--[[Inscribed Pyrestone          ]] {39733, false, Content.T6, CraftPrefix.JEWELCRAFTING, {nometa=1, epic=1, orange=1, red=1, yellow=1, inscribed=1, pyrestone=1, critical=1, physical=1, strength=1, ["5"]=1, ["7"]=1}},
		--[[Jagged Seaspray Emerald      ]] {39742, false, Content.T6, CraftPrefix.JEWELCRAFTING, {nometa=1, epic=1, green=1, jagged=1, seaspray=1, emerald=1, critical=1, physical=1, stamina=1, ["5"]=1, ["7"]=1}},
		--[[Luminous Pyrestone           ]] {39735, false, Content.T6, CraftPrefix.JEWELCRAFTING, {nometa=1, epic=1, orange=1, red=1, yellow=1, luminous=1, pyrestone=1, heal=1, intellect=1, ["11"]=1, ["5"]=1}},
		--[[Lustrous Empyrean Sapphire   ]] {39717, false, Content.T6, CraftPrefix.JEWELCRAFTING, {nometa=1, epic=1, pure=1, blue=1, lustrous=1, empyrean=1, sapphire=1, mana=1, mp5=1, regen=1, ["4"]=1}},
		--[[Mystic Lionseye              ]] {39724, false, Content.T6, CraftPrefix.JEWELCRAFTING, {nometa=1, epic=1, pure=1, yellow=1, mystic=1, lionseye=1, resilience=1, res=1, pvp=1, ["10"]=1}},
		--[[Potent Pyrestone             ]] {39734, false, Content.T6, CraftPrefix.JEWELCRAFTING, {nometa=1, epic=1, orange=1, red=1, yellow=1, potent=1, pyrestone=1, spell=1, critical=1, spellcrit=1, damage=1, spelldamage=1, sp=1, ["5"]=1, ["6"]=1}},
		--[[Quick Lionseye               ]] {47056, false, Content.SW, CraftPrefix.JEWELCRAFTING, {nometa=1, epic=1, pure=1, yellow=1, quick=1, lionseye=1, spell=1, haste=1, ["10"]=1}},
		--[[Radiant Seaspray Emerald     ]] {39740, false, Content.T6, CraftPrefix.JEWELCRAFTING, {nometa=1, epic=1, green=1, radiant=1, seaspray=1, emerald=1, spell=1, critical=1, spellcrit=1, penetration=1, spen=1, ["5"]=1, ["6"]=1}},
		--[[Reckless Pyrestone           ]] {47055, false, Content.SW, CraftPrefix.JEWELCRAFTING, {nometa=1, epic=1, orange=1, red=1, yellow=1, reckless=1, pyrestone=1, spell=1, haste=1, damage=1, spelldamage=1, sp=1, ["5"]=1, ["6"]=1}},
		--[[Rigid Lionseye               ]] {39721, false, Content.T6, CraftPrefix.JEWELCRAFTING, {nometa=1, epic=1, pure=1, yellow=1, rigid=1, lionseye=1, hit=1, physical=1, ["10"]=1}},
		--[[Royal Shadowsong Amethyst    ]] {39732, false, Content.T6, CraftPrefix.JEWELCRAFTING, {nometa=1, epic=1, purple=1, red=1, blue=1, royal=1, shadowsong=1, amethyst=1, heal=1, mana=1, mp5=1, regen=1, ["11"]=1, ["2"]=1}},
		--[[Runed Crimson Spinel         ]] {39711, false, Content.T6, CraftPrefix.JEWELCRAFTING, {nometa=1, epic=1, pure=1, red=1, runed=1, crimson=1, spinel=1, spell=1, damage=1, spelldamage=1, sp=1, ["12"]=1}},
		--[[Shifting Shadowsong Amethyst ]] {39728, false, Content.T6, CraftPrefix.JEWELCRAFTING, {nometa=1, epic=1, purple=1, red=1, blue=1, shifting=1, shadowsong=1, amethyst=1, agility=1, stamina=1, ["5"]=1, ["7"]=1}},
		--[[Smooth Lionseye              ]] {39720, false, Content.T6, CraftPrefix.JEWELCRAFTING, {nometa=1, epic=1, pure=1, yellow=1, smooth=1, lionseye=1, critical=1, physical=1, ["10"]=1}},
		--[[Solid Empyrean Sapphire      ]] {39715, false, Content.T6, CraftPrefix.JEWELCRAFTING, {nometa=1, epic=1, pure=1, blue=1, solid=1, empyrean=1, sapphire=1, stamina=1, onlystamina=1, ["15"]=1}},
		--[[Sovereign Shadowsong Amethyst]] {39727, false, Content.T6, CraftPrefix.JEWELCRAFTING, {nometa=1, epic=1, purple=1, red=1, blue=1, sovereign=1, shadowsong=1, amethyst=1, strength=1, stamina=1, ["5"]=1, ["7"]=1}},
		--[[Sparkling Empyrean Sapphire  ]] {39716, false, Content.T6, CraftPrefix.JEWELCRAFTING, {nometa=1, epic=1, pure=1, blue=1, sparkling=1, empyrean=1, sapphire=1, spirit=1, ["10"]=1}},
		--[[Steady Seaspray Emerald      ]] {47054, false, Content.SW, CraftPrefix.JEWELCRAFTING, {nometa=1, epic=1, green=1, steady=1, seaspray=1, emerald=1, resilience=1, res=1, pvp=1, stamina=1, ["5"]=1, ["7"]=1}},
		--[[Stormy Empyrean Sapphire     ]] {39718, false, Content.T6, CraftPrefix.JEWELCRAFTING, {nometa=1, epic=1, pure=1, blue=1, stormy=1, empyrean=1, sapphire=1, spell=1, penetration=1, spen=1, ["13"]=1}},
		--[[Subtle Crimson Spinel        ]] {39713, false, Content.T6, CraftPrefix.JEWELCRAFTING, {nometa=1, epic=1, pure=1, red=1, subtle=1, crimson=1, spinel=1, dodge=1, ["10"]=1}},
		--[[Teardrop Crimson Spinel      ]] {39710, false, Content.T6, CraftPrefix.JEWELCRAFTING, {nometa=1, epic=1, pure=1, red=1, teardrop=1, crimson=1, spinel=1, heal=1, ["22"]=1}},
		--[[Thick Lionseye               ]] {39723, false, Content.T6, CraftPrefix.JEWELCRAFTING, {nometa=1, epic=1, pure=1, yellow=1, thick=1, lionseye=1, defense=1, ["10"]=1}},
		--[[Veiled Pyrestone             ]] {39737, false, Content.T6, CraftPrefix.JEWELCRAFTING, {nometa=1, epic=1, orange=1, red=1, yellow=1, veiled=1, pyrestone=1, spell=1, hit=1, spellhit=1, damage=1, spelldamage=1, sp=1, ["5"]=1, ["6"]=1,}},
		--[[Void Sphere                  ]] {28028, false, Content.T4, CraftPrefix.ENCHANTING,    {nometa=1, epic=1, void=1, sphere=1, resistance=1, res=1, ["4"]=1}},
		--[[Wicked Pyrestone             ]] {39738, false, Content.T6, CraftPrefix.JEWELCRAFTING, {nometa=1, epic=1, orange=1, red=1, yellow=1, wicked=1, pyrestone=1, critical=1, physical=1, attack=1, power=1, ap=1, ["5"]=1, ["10"]=1}},
		-- Meta
		--[[Bracing Earthstorm Diamond   ]] {32867, false, Content.T4, CraftPrefix.JEWELCRAFTING, {metagem=1, bracing=1, earthstorm=1, diamond=1, heal=1, threat=1, ["26"]=1, ["2"]=1}},
		--[[Brutal Earthstorm Diamond    ]] {32869, false, Content.T4, CraftPrefix.JEWELCRAFTING, {metagem=1, brutal=1, earthstorm=1, diamond=1, physical=1, damage=1, spelldamage=1, stun=1, ["3"]=1}},
		--[[Chaotic Skyfire Diamond      ]] {44794, false, Content.T4, CraftPrefix.JEWELCRAFTING, {metagem=1, chaotic=1, skyfire=1, diamond=1, spell=1, critical=1, spellcrit=1, damage=1, spelldamage=1, ["12"]=1, ["3"]=1}},
		--[[Destructive Skyfire Diamond  ]] {32871, false, Content.T4, CraftPrefix.JEWELCRAFTING, {metagem=1, destructive=1, skyfire=1, diamond=1, spell=1, critical=1, spellcrit=1, reflect=1, ["14"]=1, ["1"]=1}},
		--[[Ember Skyfire Diamond        ]] {46601, false, Content.SW, CraftPrefix.JEWELCRAFTING, {metagem=1, ember=1, skyfire=1, diamond=1, spell=1, damage=1, spelldamage=1, sp=1, intellect=1, ["14"]=1, ["2"]=1}},
		--[[Enigmatic Skyfire Diamond    ]] {32874, false, Content.T4, CraftPrefix.JEWELCRAFTING, {metagem=1, enigmatic=1, skyfire=1, diamond=1, critical=1, physical=1, snare=1, root=1, resistance=1, res=1, ["12"]=1, ["5"]=1}},
		--[[Eternal Earthstorm Diamond   ]] {46597, false, Content.SW, CraftPrefix.JEWELCRAFTING, {metagem=1, eternal=1, earthstorm=1, diamond=1, defense=1, shield=1, ["12"]=1, ["10"]=1}}, -- block=1, removed so it isn't included with shield enchant
		--[[Insightful Earthstorm Diamond]] {32870, false, Content.T4, CraftPrefix.JEWELCRAFTING, {metagem=1, insightful=1, earthstorm=1, diamond=1, intellect=1, restore=1, mana=1, cast=1, ["12"]=1}},
		--[[Mystical Skyfire Diamond     ]] {32872, false, Content.T4, CraftPrefix.JEWELCRAFTING, {metagem=1, mystical=1, skyfire=1, diamond=1, spell=1, cast=1, speed=1}},
		--[[Powerful Earthstorm Diamond  ]] {32866, false, Content.T4, CraftPrefix.JEWELCRAFTING, {metagem=1, powerful=1, earthstorm=1, diamond=1, stamina=1, stun=1, resistance=1, res=1, ["18"]=1, ["5"]=1}},
		--[[Relentless Earthstorm Diamond]] {39961, false, Content.T4, CraftPrefix.JEWELCRAFTING, {metagem=1, relentless=1, earthstorm=1, diamond=1, agility=1, critical=1, physical=1, ["12"]=1}},
		--[[Swift Skyfire Diamond        ]] {32873, false, Content.T4, CraftPrefix.JEWELCRAFTING, {metagem=1, swift=1, skyfire=1, diamond=1, attack=1, power=1, ap=1, minor=1, run=1, speed=1}},
		--[[Tenacious Earthstorm Diamond ]] {32868, false, Content.T4, CraftPrefix.JEWELCRAFTING, {metagem=1, tenacious=1, earthstorm=1, diamond=1, defense=1, restore=1, health=1, ["12"]=1}},
		--[[Thundering Skyfire Diamond   ]] {39963, false, Content.T4, CraftPrefix.JEWELCRAFTING, {metagem=1, thundering=1, skyfire=1, diamond=1, physical=1,attack=1, speed=1}},
	},
	----------------------------------------
	-- Engineering
	----------------------------------------
	["ENGINEERING"] = { -- capatalized to not be a major keyword
		--[[flying machine             ]] {44155, false, Content.T4, CraftPrefix.ENGINEERING, {flying=1, machine=1, heli=1, helicopter=1, copter=1, slow=1, rare=1, blue=1}},
		--[[turbocharged flying machine]] {44157, false, Content.T4, CraftPrefix.ENGINEERING, {flying=1, machine=1, heli=1, helicopter=1, copter=1, turbocharged=1, turbo=1, charged=1, epic=1, purple=1, fast=1}},
	},
	["bomb"] = {
		--[[super sapper charge ]] {30560, false, Content.T4, CraftPrefix.ENGINEERING, {super=1, sapper=1, charge=1}},
		--[[frost grenades      ]] {39973, false, Content.T4, CraftPrefix.ENGINEERING, {frost=1, freeze=1}},
		--[[adamantite grenade  ]] {30311, false, Content.T4, CraftPrefix.ENGINEERING, {adamantite=1, stun=1}},
		--[[the bigger one      ]] {30558, false, Content.T4, CraftPrefix.ENGINEERING, {bigger=1, one=1, stun=1}},
		--[[fel iron bomb       ]] {30310, false, Content.T4, CraftPrefix.ENGINEERING, {fel=1, iron=1, stun=1}},
		--[[arcane bomb         ]] {19831, false, Content.T4, CraftPrefix.ENGINEERING, {arcane=1, mana=1, silence=1}},
	},
	["scope"] = {
		--[[stabilized eternium scope   ]] {30334, false, Content.T4, CraftPrefix.ENGINEERING, {stabilized=1, stable=1, eternium=1, critical=1, ["28"]=1}},
		--[[khorium scope               ]] {30332, false, Content.T4, CraftPrefix.ENGINEERING, {khorium=1, damage=1, ["12"]=1}},
		--[[biznicks 247x128 accurascope]] {22793, false, Content.T4, CraftPrefix.ENGINEERING, {mc=1, molten=1, core=1, biznicks=1, bizniks=1, ["247"]=1, ["128"]=1, accura=1, accurascope=1, hit=1, physical=1, ["30"]=1}},
		--[[adamantite scope            ]] {30329, false, Content.T4, CraftPrefix.ENGINEERING, {adamantite=1, damage=1, ["10"]=1}},
	},
	----------------------------------------
	-- Leatherworking
	----------------------------------------
	["LEATHERWORKING"] = { -- capatalized to not be a major keyword
		--[[Heavy Knothide Leather       ]] {32455, false, Content.T4, CraftPrefix.LEATHERWORKING, {heavy=1, knothide=1, knot=1, hide=1, leather=1}},
		--[[Knothide Leather             ]] {32454, false, Content.T4, CraftPrefix.LEATHERWORKING, {knothide=1, leather=1}},
		--[[Netherscale Ammo Pouch       ]] {44768, false, Content.T4, CraftPrefix.LEATHERWORKING, {netherscale=1, nether=1, scale=1, ammo=1, pouch=1}},
		--[[Quiver of a Thousand Feathers]] {44359, false, Content.T4, CraftPrefix.LEATHERWORKING, {quiver=1, thousand=1, ["1000"]=1, feathers=1, feather=1}},
		--[[Riding Crop                  ]] {32461, false, Content.T4, CraftPrefix.LEATHERWORKING, {riding=1, crop=1, mount=1, speed=1, trinket=1, ["10"]=1}},
	},
	["kit"] = {
		--[[Arcane Armor Kit      ]] {35524, false, Content.T4, CraftPrefix.LEATHERWORKING, {armor=1, resistance=1, res=1, ["8"]=1, arcane=1}},
		--[[Core Armor Kit        ]] {22727, false, Content.T4, CraftPrefix.LEATHERWORKING, {armor=1, core=1, ["5"]=1, defense=1}},
		--[[Flame Armor Kit       ]] {35521, false, Content.T4, CraftPrefix.LEATHERWORKING, {armor=1, resistance=1, res=1, ["8"]=1, flame=1}},
		--[[Frost Armor Kit       ]] {35522, false, Content.T4, CraftPrefix.LEATHERWORKING, {armor=1, resistance=1, res=1, ["8"]=1, frost=1}},
		--[[Heavy Knothide Armor  ]] {44970, false, Content.T4, CraftPrefix.LEATHERWORKING, {heavy=1, knothide=1, knot=1, hide=1, armor=1, stamina=1, health=1, ["10"]=1}},
		--[[Knothide Armor        ]] {32456, false, Content.T4, CraftPrefix.LEATHERWORKING, {knothide=1, knot=1, hide=1, armor=1, stamina=1, health=1, ["8"]=1}},
		--[[Magister's Armor Kit  ]] {32458, false, Content.T4, CraftPrefix.LEATHERWORKING, {armor=1, magister=1, magi=1, mp5=1, mana=1, regen=1, ["3"]=1}},
		--[[Nature Armor Kit      ]] {35523, false, Content.T4, CraftPrefix.LEATHERWORKING, {armor=1, resistance=1, res=1, ["8"]=1, nature=1}},
		--[[Shadow Armor Kit      ]] {35520, false, Content.T4, CraftPrefix.LEATHERWORKING, {armor=1, resistance=1, res=1, ["8"]=1, shadow=1}},
		--[[Vindicator's Armor Kit]] {32457, false, Content.T4, CraftPrefix.LEATHERWORKING, {armor=1, vindicator=1, vind=1, ["8"]=1, defense=1}},
	},
	----------------------------------------
	-- Tailoring
	----------------------------------------
	["TAILORING"] = { -- capatalized to not be a major keyword
		--[[Admiral's hat             ]] {12081, false, Content.T4, CraftPrefix.TAILORING, {admiral=1, admirals=1, pirate=1, pirates=1, hat=1}},
		--[[Bolt of Imbued Netherweave]] {26747, false, Content.T4, CraftPrefix.TAILORING, {bolt=1, imbued=1, netherweave=1}},
		--[[Bolt of Netherweave       ]] {26745, false, Content.T4, CraftPrefix.TAILORING, {bolt=1, netherweave=1}},
		--[[Bolt of Soulcloth         ]] {26750, false, Content.T4, CraftPrefix.TAILORING, {bolt=1, soulcloth=1, soul=1, cloth=1}},
		--[[Primal Mooncloth          ]] {26751, false, Content.T4, CraftPrefix.TAILORING, {primal=1, mooncloth=1, moon=1, cloth=1}},
		--[[Shadowcloth               ]] {36686, false, Content.T4, CraftPrefix.TAILORING, {shadowcloth=1, shadow=1, cloth=1}},
		--[[Shadowcloth               ]] {36686, true,  Content.T4, CraftPrefix.TAILORING, {shadowcloth=1}},
		--[[Spellcloth                ]] {31373, false, Content.T4, CraftPrefix.TAILORING, {spellcloth=1, spell=1, cloth=1}},
		--[[Spellcloth                ]] {31373, true,  Content.T4, CraftPrefix.TAILORING, {spellcloth=1}},
	},
	["shirt"] = {
		--[[rich purple silk shirt   ]] {3872, false, Content.T4, CraftPrefix.TAILORING, {rich=1, purple=1, silk=1}},
		--[[bright yellow shirt      ]] {3869, false, Content.T4, CraftPrefix.TAILORING, {bright=1, yellow=1}},
		--[[blue linen shirt         ]] {2394, false, Content.T4, CraftPrefix.TAILORING, {blue=1, linen=1}},
		--[[brown linen shirt        ]] {3915, false, Content.T4, CraftPrefix.TAILORING, {brown=1, linen=1}},
		--[[white linen shirt        ]] {2393, false, Content.T4, CraftPrefix.TAILORING, {white=1, linen=1}},
		--[[gray woolen shirt        ]] {2406, false, Content.T4, CraftPrefix.TAILORING, {gray=1, grey=1, woolen=1, wool=1}},
		--[[stylish red shirt        ]] {3866, false, Content.T4, CraftPrefix.TAILORING, {stylish=1, red=1}},
		--[[green linen shirt        ]] {2396, false, Content.T4, CraftPrefix.TAILORING, {green=1, linen=1}},
		--[[dark silk shirt          ]] {3870, false, Content.T4, CraftPrefix.TAILORING, {dark=1, black=1, silk=1}},
		--[[white swashbucklers shirt]] {8483, false, Content.T4, CraftPrefix.TAILORING, {white=1, swashbuckler=1, swashbucklers=1}},
		--[[formal white shirt       ]] {3871, false, Content.T4, CraftPrefix.TAILORING, {formal=1, white=1}},
		--[[red swashbucklers shirt  ]] {8489, false, Content.T4, CraftPrefix.TAILORING, {red=1, swashbuckler=1, swashbucklers=1}},
		--[[black swashbucklers shirt]] {3873, false, Content.T4, CraftPrefix.TAILORING, {black=1, swashbuckler=1, swashbucklers=1}},
	},
}

-- Sometimes people ask for things that don't exist. This table will list possibilities for enchant
-- slots (except weapons because there's too many!)
PleaseLinkData.suggestions = {
	["boots"] = "boar, cat, dexterity, stamina, spirit, vitality, surefooted",
	["bracer"] = "attack power, strength, stamina, defense, intellect, mp5, spellpower, stats, healing, spirit",
	["chest"] = "defense, health, mana, stats, resilience, spirit, mp5",
	["cloak"] = "dodge, agility, armor, spell penetration, stealth, defense, subtlety, resistance, arcane/fire/nature/shadow resistance",
	["gloves"] = "attack power, agility, strength, healing, spell power, spell crit, spell hit, threat, haste, riding",
	["legs"] = "healing, spell damage, physical dps, tank",
	["shield"] = "intellect, stamina, resilience, resistance, block",
	["ring"] = "healing, spellpower, stats, weapon damage",
}

-- Craftable things in this table are searched for by name instead of keywords
-- Format: [searchable name] = {spell ID, CraftPrefix}
-- Content level isn't important because it's a specific search so they surely want to see it
-- Some common items can be listed multiple times with alternative names (like mana potion injector/mana injector)
PleaseLinkData.craftNameList = {
	-- Alchemy
	["sorcerers alchemist stone"] = {47048, CraftPrefix.ALCHEMY},
	["redeemers alchemist stone"] = {47049, CraftPrefix.ALCHEMY},
	["guardians alchemist stone"] = {47046, CraftPrefix.ALCHEMY},
	["assassins alchemist stone"] = {47050, CraftPrefix.ALCHEMY},
	["alchemists stone"] = {17632, CraftPrefix.ALCHEMY},
	["frost oil"] = {3454, CraftPrefix.ALCHEMY},
	["fire oil"] = {7837, CraftPrefix.ALCHEMY},
	["shadow oil"] = {3449, CraftPrefix.ALCHEMY},
	["ghost dye"] = {11473, CraftPrefix.ALCHEMY},
	-- Blacksmithing
	["wildguard leggings"] = {38475, CraftPrefix.BLACKSMITHING},
	["wildguard helm"] = {38476, CraftPrefix.BLACKSMITHING},
	["wildguard breastplate"] = {38473, CraftPrefix.BLACKSMITHING},
	["wicked edge of the planes"] = {36260, CraftPrefix.BLACKSMITHING},
	["twisting nether chain shirt"] = {34530, CraftPrefix.BLACKSMITHING},
	["swiftsteel shoulders"] = {41133, CraftPrefix.BLACKSMITHING},
	["swiftsteel bracers"] = {41132, CraftPrefix.BLACKSMITHING},
	["stormherald"] = {36263, CraftPrefix.BLACKSMITHING},
	["shadesteel sabots"] = {40033, CraftPrefix.BLACKSMITHING},
	["shadesteel greaves"] = {40035, CraftPrefix.BLACKSMITHING},
	["shadesteel girdle"] = {40036, CraftPrefix.BLACKSMITHING},
	["shadesteel bracers"] = {40034, CraftPrefix.BLACKSMITHING},
	["red havoc boots"] = {36392, CraftPrefix.BLACKSMITHING},
	["red belt of battle"] = {36390, CraftPrefix.BLACKSMITHING},
	["mooncleaver"] = {34544, CraftPrefix.BLACKSMITHING},
	["lionheart executioner"] = {36259, CraftPrefix.BLACKSMITHING},
	["lionheart champion"] = {34540, CraftPrefix.BLACKSMITHING},
	["iceguard leggings"] = {38478, CraftPrefix.BLACKSMITHING},
	["iceguard helm"] = {38479, CraftPrefix.BLACKSMITHING},
	["iceguard breastplate"] = {38477, CraftPrefix.BLACKSMITHING},
	["embrace of the twisting nether"] = {36256, CraftPrefix.BLACKSMITHING},
	["dragonstrike"] = {36262, CraftPrefix.BLACKSMITHING},
	["dragonmaw"] = {34546, CraftPrefix.BLACKSMITHING},
	["deep thunder"] = {34548, CraftPrefix.BLACKSMITHING},
	["dawnsteel shoulders"] = {41135, CraftPrefix.BLACKSMITHING},
	["dawnsteel bracers"] = {41134, CraftPrefix.BLACKSMITHING},
	["bulwark of the ancient kings"] = {36257, CraftPrefix.BLACKSMITHING},
	["bulwark of kings"] = {34534, CraftPrefix.BLACKSMITHING},
	["boots of the protector"] = {36391, CraftPrefix.BLACKSMITHING},
	["bloodmoon"] = {36261, CraftPrefix.BLACKSMITHING},
	["blazeguard"] = {34537, CraftPrefix.BLACKSMITHING},
	["blazefury"] = {36258, CraftPrefix.BLACKSMITHING},
	["black planar edge"] = {34542, CraftPrefix.BLACKSMITHING},
	["belt of the guardian"] = {36389, CraftPrefix.BLACKSMITHING},
	["greater ward of shielding"] = {29729, CraftPrefix.BLACKSMITHING},
	["swiftsteel gloves"] = {29648, CraftPrefix.BLACKSMITHING},
	["ragesteel breastplate"] = {29645, CraftPrefix.BLACKSMITHING},
	["earthpeace breastplate"] = {29649, CraftPrefix.BLACKSMITHING},
	["sunblessed gauntlets"] = {46140, CraftPrefix.BLACKSMITHING},
	["sunblessed breastplate"] = {46142, CraftPrefix.BLACKSMITHING},
	["hard khorium battleplate"] = {46144, CraftPrefix.BLACKSMITHING},
	["hard khorium battlefists"] = {46141, CraftPrefix.BLACKSMITHING},
	["ragesteel shoulders"] = {42662, CraftPrefix.BLACKSMITHING},
	["ragesteel helm"] = {29643, CraftPrefix.BLACKSMITHING},
	["ragesteel gloves"] = {29642, CraftPrefix.BLACKSMITHING},
	["khorium boots"] = {29630, CraftPrefix.BLACKSMITHING},
	["flamebane breastplate"] = {29617, CraftPrefix.BLACKSMITHING},
	["felsteel helm"] = {29621, CraftPrefix.BLACKSMITHING},
	["enchanted adamantite leggings"] = {29613, CraftPrefix.BLACKSMITHING},
	["storm helm"] = {29663, CraftPrefix.BLACKSMITHING},
	["steelgrip gauntlets"] = {29662, CraftPrefix.BLACKSMITHING},
	["runic hammer"] = {29696, CraftPrefix.BLACKSMITHING},
	["oathkeepers helm"] = {29668, CraftPrefix.BLACKSMITHING},
	["khorium champion"] = {29693, CraftPrefix.BLACKSMITHING},
	["helm of the stalwart defender"] = {29664, CraftPrefix.BLACKSMITHING},
	["hand of eternity"] = {29700, CraftPrefix.BLACKSMITHING},
	["hammer of righteous might"] = {43846, CraftPrefix.BLACKSMITHING},
	["gauntlets of the iron tower"] = {29622, CraftPrefix.BLACKSMITHING},
	["felsteel reaper"] = {29695, CraftPrefix.BLACKSMITHING},
	["felsteel longblade"] = {29692, CraftPrefix.BLACKSMITHING},
	["felfury gauntlets"] = {29658, CraftPrefix.BLACKSMITHING},
	["fel hardened maul"] = {29697, CraftPrefix.BLACKSMITHING},
	["fel edged battleaxe"] = {29694, CraftPrefix.BLACKSMITHING},
	["eternium runed blade"] = {29698, CraftPrefix.BLACKSMITHING},
	["dirge"] = {29699, CraftPrefix.BLACKSMITHING},
	["bracers of the green fortress"] = {29671, CraftPrefix.BLACKSMITHING},
	["blessed bracers"] = {29672, CraftPrefix.BLACKSMITHING},
	["black felsteel bracers"] = {29669, CraftPrefix.BLACKSMITHING},
	["felsteel shield spike"] = {29657, CraftPrefix.BLACKSMITHING},
	["khorium pants"] = {29629, CraftPrefix.BLACKSMITHING},
	["khorium belt"] = {29628, CraftPrefix.BLACKSMITHING},
	["flamebane gloves"] = {29616, CraftPrefix.BLACKSMITHING},
	["felsteel leggings"] = {29620, CraftPrefix.BLACKSMITHING},
	["felsteel gloves"] = {29619, CraftPrefix.BLACKSMITHING},
	["enchanted adamantite breastplate"] = {29610, CraftPrefix.BLACKSMITHING},
	["enchanted adamantite boots"] = {29611, CraftPrefix.BLACKSMITHING},
	["enchanted adamantite belt"] = {29608, CraftPrefix.BLACKSMITHING},
	["flamebane helm"] = {29615, CraftPrefix.BLACKSMITHING},
	["flamebane bracers"] = {29614, CraftPrefix.BLACKSMITHING},
	["felsteel whisper knives"] = {34983, CraftPrefix.BLACKSMITHING},
	["thunder"] = {34547, CraftPrefix.BLACKSMITHING},
	["planar edge"] = {34541, CraftPrefix.BLACKSMITHING}, -- the planar edge
	["nether chain shirt"] = {34529, CraftPrefix.BLACKSMITHING},
	["lunar crescent"] = {34543, CraftPrefix.BLACKSMITHING},
	["lionheart blade"] = {34538, CraftPrefix.BLACKSMITHING},
	["fireguard"] = {34535, CraftPrefix.BLACKSMITHING},
	["drakefist hammer"] = {34545, CraftPrefix.BLACKSMITHING},
	["breastplate of kings"] = {34533, CraftPrefix.BLACKSMITHING},
	["adamantite breastplate"] = {29606, CraftPrefix.BLACKSMITHING},
	["adamantite rapier"] = {29571, CraftPrefix.BLACKSMITHING},
	["adamantite plate gloves"] = {29605, CraftPrefix.BLACKSMITHING},
	["adamantite plate bracers"] = {29603, CraftPrefix.BLACKSMITHING},
	["adamantite dagger"] = {29569, CraftPrefix.BLACKSMITHING},
	["adamantite cleaver"] = {29568, CraftPrefix.BLACKSMITHING},
	["windforged rapier"] = {36131, CraftPrefix.BLACKSMITHING},
	["stormforged hauberk"] = {36130, CraftPrefix.BLACKSMITHING},
	["stormforged axe"] = {36134, CraftPrefix.BLACKSMITHING},
	["stoneforged claymore"] = {36133, CraftPrefix.BLACKSMITHING},
	["skyforged great axe"] = {36135, CraftPrefix.BLACKSMITHING},
	["lavaforged warhammer"] = {36136, CraftPrefix.BLACKSMITHING},
	["heavy earthforged breastplate"] = {36129, CraftPrefix.BLACKSMITHING},
	["great earthforged hammer"] = {36137, CraftPrefix.BLACKSMITHING},
	["fel iron breastplate"] = {29550, CraftPrefix.BLACKSMITHING},
	["adamantite maul"] = {29566, CraftPrefix.BLACKSMITHING},
	["lesser rune of warding"] = {32284, CraftPrefix.BLACKSMITHING},
	["fel iron greatsword"] = {29565, CraftPrefix.BLACKSMITHING},
	["fel iron chain tunic"] = {29556, CraftPrefix.BLACKSMITHING},
	["fel iron plate pants"] = {29549, CraftPrefix.BLACKSMITHING},
	["fel iron plate boots"] = {29548, CraftPrefix.BLACKSMITHING},
	["fel iron hammer"] = {29558, CraftPrefix.BLACKSMITHING},
	["fel iron chain bracers"] = {29553, CraftPrefix.BLACKSMITHING},
	["fel iron hatchet"] = {29557, CraftPrefix.BLACKSMITHING},
	["fel iron chain gloves"] = {29552, CraftPrefix.BLACKSMITHING},
	["fel iron plate belt"] = {29547, CraftPrefix.BLACKSMITHING},
	["sulfuron hammer"] = {21161, CraftPrefix.BLACKSMITHING},
	["eternium rod"] = {32657, CraftPrefix.BLACKSMITHING},
	["adamantite rod"] = {32656, CraftPrefix.BLACKSMITHING},
	["fel iron rod"] = {32655, CraftPrefix.BLACKSMITHING},
	["arcanite rod"] = {20201, CraftPrefix.BLACKSMITHING},
	["silver rod"] = {7818, CraftPrefix.BLACKSMITHING},
	["truesilver rod"] = {14380, CraftPrefix.BLACKSMITHING},
	["golden rod"] = {14379, CraftPrefix.BLACKSMITHING},
	-- Enchanting
	["runed eternium rod"] = {32667, CraftPrefix.ENCHANTING},
	["runed adamantite rod"] = {32665, CraftPrefix.ENCHANTING},
	["runed fel iron rod"] = {32664, CraftPrefix.ENCHANTING},
	["runed arcanite rod"] = {20051, CraftPrefix.ENCHANTING},
	["enchanted thorium"] = {17180, CraftPrefix.ENCHANTING},
	["enchanted leather"] = {17181, CraftPrefix.ENCHANTING},
	["runed truesilver rod"] = {13702, CraftPrefix.ENCHANTING},
	["runed golden rod"] = {13628, CraftPrefix.ENCHANTING},
	["runed silver rod"] = {7795, CraftPrefix.ENCHANTING},
	["runed copper rod"] = {7421, CraftPrefix.ENCHANTING},
	-- Engineering
	["rough blasting powder"] = {3918, CraftPrefix.ENGINEERING},
	["handful of copper bolts"] = {3922, CraftPrefix.ENGINEERING},
	["arclight spanner"] = {7430, CraftPrefix.ENGINEERING},
	["copper tube"] = {3924, CraftPrefix.ENGINEERING},
	["copper modulator"] = {3926, CraftPrefix.ENGINEERING},
	["coarse blasting powder"] = {3929, CraftPrefix.ENGINEERING},
	["mechanical squirrel"] = {3928, CraftPrefix.ENGINEERING},
	["silver contact"] = {3973, CraftPrefix.ENGINEERING},
	["practice lock"] = {8334, CraftPrefix.ENGINEERING},
	["bronze tube"] = {3938, CraftPrefix.ENGINEERING},
	["heavy blasting powder"] = {3945, CraftPrefix.ENGINEERING},
	["small blue rocket"] = {26416, CraftPrefix.ENGINEERING},
	["small green rocket"] = {26417, CraftPrefix.ENGINEERING},
	["small red rocket"] = {26418, CraftPrefix.ENGINEERING},
	["whirring bronze gizmo"] = {3942, CraftPrefix.ENGINEERING},
	["ornate spyglass"] = {6458, CraftPrefix.ENGINEERING},
	["bronze framework"] = {3953, CraftPrefix.ENGINEERING},
	["blue firework"] = {23067, CraftPrefix.ENGINEERING},
	["green firework"] = {23068, CraftPrefix.ENGINEERING},
	["red firework"] = {23066, CraftPrefix.ENGINEERING},
	["gold power core"] = {12584, CraftPrefix.ENGINEERING},
	["iron strut"] = {3958, CraftPrefix.ENGINEERING},
	["gyrochronatom"] = {3961, CraftPrefix.ENGINEERING},
	["solid blasting powder"] = {12585, CraftPrefix.ENGINEERING},
	["large blue rocket"] = {26420, CraftPrefix.ENGINEERING},
	["large green rocket"] = {26421, CraftPrefix.ENGINEERING},
	["large red rocket"] = {26422, CraftPrefix.ENGINEERING},
	["gyromatic microadjustor"] = {12590, CraftPrefix.ENGINEERING},
	["snowmaster 9000"] = {21940, CraftPrefix.ENGINEERING},
	["mithril tube"] = {12589, CraftPrefix.ENGINEERING},
	["unstable trigger"] = {12591, CraftPrefix.ENGINEERING},
	["mechanical dragonling"] = {3969, CraftPrefix.ENGINEERING},
	["lil smoky"] = {15633, CraftPrefix.ENGINEERING},
	["pet bombling"] = {15628, CraftPrefix.ENGINEERING},
	["mithril casing"] = {12599, CraftPrefix.ENGINEERING},
	["blue rocket cluster"] = {26423, CraftPrefix.ENGINEERING},
	["green rocket cluster"] = {26424, CraftPrefix.ENGINEERING},
	["red rocket cluster"] = {26425, CraftPrefix.ENGINEERING},
	["parachute cloak"] = {12616, CraftPrefix.ENGINEERING},
	["firework launcher"] = {26442, CraftPrefix.ENGINEERING},
	["deepdive helmet"] = {12617, CraftPrefix.ENGINEERING},
	["gnomish battle chicken"] = {12906, CraftPrefix.ENGINEERING},
	["gnomish mind control cap"] = {12907, CraftPrefix.ENGINEERING},
	["goblin rocket helmet"] = {12758, CraftPrefix.ENGINEERING},
	["snake burst firework"] = {23507, CraftPrefix.ENGINEERING},
	["mithril mechanical dragonling"] = {12624, CraftPrefix.ENGINEERING},
	["tranquil mechanical yeti"] = {26011, CraftPrefix.ENGINEERING},
	["world enlarger"] = {23129, CraftPrefix.ENGINEERING},
	["truesilver transformer"] = {23071, CraftPrefix.ENGINEERING},
	["thorium widget"] = {19791, CraftPrefix.ENGINEERING},
	["alarmobot"] = {23096, CraftPrefix.ENGINEERING},
	["goblin jumper cables xl"] = {23078, CraftPrefix.ENGINEERING},
	["jumper cables"] = {23078, CraftPrefix.ENGINEERING}, -- goblin jumper cables xl
	["lifelike mechanical toad"] = {19793, CraftPrefix.ENGINEERING},
	["fused wiring"] = {39895, CraftPrefix.ENGINEERING},
	["large blue rocket cluster"] = {26426, CraftPrefix.ENGINEERING},
	["large green rocket cluster"] = {26427, CraftPrefix.ENGINEERING},
	["large red rocket cluster"] = {26428, CraftPrefix.ENGINEERING},
	["firework cluster launcher"] = {26443, CraftPrefix.ENGINEERING},
	["masterwork target dummy"] = {19814, CraftPrefix.ENGINEERING},
	["target dummy"] = {19814, CraftPrefix.ENGINEERING}, -- masterwork target dummy
	["thorium tube"] = {19795, CraftPrefix.ENGINEERING},
	["delicate arcanite converter"] = {19815, CraftPrefix.ENGINEERING},
	["icy blasting primers"] = {39971, CraftPrefix.ENGINEERING},
	["gnomish flame turret"] = {30568, CraftPrefix.ENGINEERING},
	["flame turret"] = {30568, CraftPrefix.ENGINEERING}, -- gnomish flame turret
	["gnomish tonk controller"] = {30573, CraftPrefix.ENGINEERING},
	["goblin tonk controller"] = {30561, CraftPrefix.ENGINEERING},
	["tonk controller"] = {30561, CraftPrefix.ENGINEERING}, -- goblin tonk controller
	["handful of fel iron bolts"] = {30305, CraftPrefix.ENGINEERING},
	["elemental blasting powder"] = {30303, CraftPrefix.ENGINEERING},
	["fel iron casing"] = {30304, CraftPrefix.ENGINEERING},
	["arcanite dragonling"] = {19830, CraftPrefix.ENGINEERING},
	["field repair bot 74a"] = {22704, CraftPrefix.ENGINEERING},
	["zapthrottle mote extractor"] = {30548, CraftPrefix.ENGINEERING},
	["adamantite frame"] = {30306, CraftPrefix.ENGINEERING},
	["crashin thrashin robot"] = {30337, CraftPrefix.ENGINEERING},
	["healing potion injector"] = {30551, CraftPrefix.ENGINEERING},
	["healing injector"] = {30551, CraftPrefix.ENGINEERING}, -- healing potion injector
	["green smoke flare"] = {30344, CraftPrefix.ENGINEERING},
	["purple smoke flare"] = {32814, CraftPrefix.ENGINEERING},
	["white smoke flare"] = {30341, CraftPrefix.ENGINEERING},
	["green flare"] = {30344, CraftPrefix.ENGINEERING}, -- green smoke flare
	["purple flare"] = {32814, CraftPrefix.ENGINEERING}, -- purple smoke flare
	["white flare"] = {30341, CraftPrefix.ENGINEERING}, -- white smoke flare
	["felsteel stabilizer"] = {30309, CraftPrefix.ENGINEERING},
	["hardened adamantite tube"] = {30307, CraftPrefix.ENGINEERING},
	["khorium power core"] = {30308, CraftPrefix.ENGINEERING},
	["gnomish poultryizer"] = {30569, CraftPrefix.ENGINEERING},
	["mana potion injector"] = {30552, CraftPrefix.ENGINEERING},
	["mana injector"] = {30552, CraftPrefix.ENGINEERING}, -- mana potion injector
	["goblin rocket launcher"] = {30563, CraftPrefix.ENGINEERING},
	["elemental seaforium charge"] = {30547, CraftPrefix.ENGINEERING},
	["seaforium charge"] = {30547, CraftPrefix.ENGINEERING}, -- elemental seaforium charge
	["rocket launcher"] = {30563, CraftPrefix.ENGINEERING}, -- goblin rocket launcher
	["rocket boots xtreme lite"] = {46697, CraftPrefix.ENGINEERING},
	["rocket boots lite"] = {46697, CraftPrefix.ENGINEERING}, -- rocket boots xtreme lite
	["rocket boots xtreme"] = {30556, CraftPrefix.ENGINEERING},
	["rocket boots"] = {30556, CraftPrefix.ENGINEERING}, -- rocket boots xtreme
	["field repair bot 110g"] = {44391, CraftPrefix.ENGINEERING},
	["field repair bot"] = {44391, CraftPrefix.ENGINEERING}, -- field repair bot 110g
	["repair bot"] = {44391, CraftPrefix.ENGINEERING}, -- field repair bot 110g
	-- Jewelcrafting
	["coronet of the verdant flame"] = {31077, CraftPrefix.JEWELCRAFTING},
	["circlet of arcane might"] = {31078, CraftPrefix.JEWELCRAFTING},
	["ring of flowing life"] = {46123, CraftPrefix.JEWELCRAFTING},
	["pendant of sunfire"] = {46125, CraftPrefix.JEWELCRAFTING},
	["loop of forged power"] = {46122, CraftPrefix.JEWELCRAFTING},
	["hard khorium choker"] = {46127, CraftPrefix.JEWELCRAFTING},
	["hard khorium band"] = {46124, CraftPrefix.JEWELCRAFTING},
	["amulet of flowing life"] = {46126, CraftPrefix.JEWELCRAFTING},
	["embrace of the dawn"] = {31072, CraftPrefix.JEWELCRAFTING},
	["crown of the sea witch"] = {41418, CraftPrefix.JEWELCRAFTING},
	["chain of the twilight owl"] = {31076, CraftPrefix.JEWELCRAFTING},
	["blazing eternium band"] = {31061, CraftPrefix.JEWELCRAFTING},
	["arcane khorium band"] = {31057, CraftPrefix.JEWELCRAFTING},
	["khorium band of leaves"] = {31056, CraftPrefix.JEWELCRAFTING},
	["eye of the night"] = {31071, CraftPrefix.JEWELCRAFTING},
	["braided eternium chain"] = {31070, CraftPrefix.JEWELCRAFTING},
	["thick felsteel necklace"] = {31067, CraftPrefix.JEWELCRAFTING},
	["living ruby pendant"] = {31068, CraftPrefix.JEWELCRAFTING},
	["khorium inferno band"] = {31055, CraftPrefix.JEWELCRAFTING},
	["khorium band of frost"] = {31054, CraftPrefix.JEWELCRAFTING},
	["delicate eternium ring"] = {31060, CraftPrefix.JEWELCRAFTING},
	["khorium band of shadows"] = {31053, CraftPrefix.JEWELCRAFTING},
	["brilliant glass"] = {47280, CraftPrefix.JEWELCRAFTING},
	["heavy felsteel ring"] = {31058, CraftPrefix.JEWELCRAFTING},
	["necklace of the deep"] = {40514, CraftPrefix.JEWELCRAFTING},
	["thick adamantite necklace"] = {31051, CraftPrefix.JEWELCRAFTING},
	["heavy adamantite ring"] = {31052, CraftPrefix.JEWELCRAFTING},
	["black pearl"] = {41415, CraftPrefix.JEWELCRAFTING}, -- the black pearl
	["brilliant pearl band"] = {41414, CraftPrefix.JEWELCRAFTING},
	["azure moonstone ring"] = {31050, CraftPrefix.JEWELCRAFTING},
	["golden draenite ring"] = {31049, CraftPrefix.JEWELCRAFTING},
	["fel iron blood ring"] = {31048, CraftPrefix.JEWELCRAFTING},
	["band of natural fire"] = {26916, CraftPrefix.JEWELCRAFTING},
	["necklace of the diamond tower"] = {26915, CraftPrefix.JEWELCRAFTING},
	-- Leatherworking
	["windhawk hauberk"] = {35585, CraftPrefix.LEATHERWORKING},
	["windhawk bracers"] = {35588, CraftPrefix.LEATHERWORKING},
	["windhawk belt"] = {35587, CraftPrefix.LEATHERWORKING},
	["waistguard of shackled souls"] = {40002, CraftPrefix.LEATHERWORKING},
	["swiftstrike shoulders"] = {41160, CraftPrefix.LEATHERWORKING},
	["swiftstrike bracers"] = {41158, CraftPrefix.LEATHERWORKING},
	["shoulders of lightning reflexes"] = {41162, CraftPrefix.LEATHERWORKING},
	["shoulderpads of renewed life"] = {41157, CraftPrefix.LEATHERWORKING},
	["redeemed soul wristguards"] = {40004, CraftPrefix.LEATHERWORKING},
	["redeemed soul moccasins"] = {40003, CraftPrefix.LEATHERWORKING},
	["redeemed soul legguards"] = {40005, CraftPrefix.LEATHERWORKING},
	["redeemed soul cinch"] = {40006, CraftPrefix.LEATHERWORKING},
	["primalstrike vest"] = {35589, CraftPrefix.LEATHERWORKING},
	["primalstrike bracers"] = {35591, CraftPrefix.LEATHERWORKING},
	["primalstrike belt"] = {35590, CraftPrefix.LEATHERWORKING},
	["netherstrike breastplate"] = {35580, CraftPrefix.LEATHERWORKING},
	["netherstrike bracers"] = {35584, CraftPrefix.LEATHERWORKING},
	["netherstrike belt"] = {35582, CraftPrefix.LEATHERWORKING},
	["monsoon belt"] = {36353, CraftPrefix.LEATHERWORKING},
	["living earth shoulders"] = {41164, CraftPrefix.LEATHERWORKING},
	["living earth bindings"] = {41163, CraftPrefix.LEATHERWORKING},
	["hurricane boots"] = {36359, CraftPrefix.LEATHERWORKING},
	["greaves of shackled souls"] = {40001, CraftPrefix.LEATHERWORKING},
	["ebon netherscale breastplate"] = {35575, CraftPrefix.LEATHERWORKING},
	["ebon netherscale bracers"] = {35577, CraftPrefix.LEATHERWORKING},
	["ebon netherscale belt"] = {35576, CraftPrefix.LEATHERWORKING},
	["bracers of shackled souls"] = {40000, CraftPrefix.LEATHERWORKING},
	["bracers of renewed life"] = {41156, CraftPrefix.LEATHERWORKING},
	["boots of utter darkness"] = {36357, CraftPrefix.LEATHERWORKING},
	["boots of the crimson hawk"] = {36358, CraftPrefix.LEATHERWORKING},
	["boots of shackled souls"] = {39997, CraftPrefix.LEATHERWORKING},
	["boots of natural grace"] = {36355, CraftPrefix.LEATHERWORKING},
	["bindings of lightning reflexes"] = {41161, CraftPrefix.LEATHERWORKING},
	["belt of the black eagle"] = {36352, CraftPrefix.LEATHERWORKING},
	["belt of natural power"] = {36349, CraftPrefix.LEATHERWORKING},
	["belt of deep shadow"] = {36351, CraftPrefix.LEATHERWORKING},
	["drums of panic"] = {35538, CraftPrefix.LEATHERWORKING},
	["sundrenched scale gloves"] = {46135, CraftPrefix.LEATHERWORKING},
	["sundrenched scale chestguard"] = {46139, CraftPrefix.LEATHERWORKING},
	["leather gauntlets of the sun"] = {46132, CraftPrefix.LEATHERWORKING},
	["leather chestguard of the sun"] = {46136, CraftPrefix.LEATHERWORKING},
	["gloves of immortal dusk"] = {46134, CraftPrefix.LEATHERWORKING},
	["fletchers gloves of the phoenix"] = {46133, CraftPrefix.LEATHERWORKING},
	["embrace of the phoenix"] = {46137, CraftPrefix.LEATHERWORKING},
	["carapace of sun and shadow"] = {46138, CraftPrefix.LEATHERWORKING},
	["windstrike gloves"] = {35568, CraftPrefix.LEATHERWORKING},
	["windslayer wraps"] = {35563, CraftPrefix.LEATHERWORKING},
	["windscale hood"] = {35560, CraftPrefix.LEATHERWORKING},
	["thick netherscale breastplate"] = {35574, CraftPrefix.LEATHERWORKING},
	["shadowprowlers chestguard"] = {42731, CraftPrefix.LEATHERWORKING},
	["shadowprowler chestguard"] = {42731, CraftPrefix.LEATHERWORKING}, -- shadowprowlers chestguard
	["shadowprowlers chest"] = {42731, CraftPrefix.LEATHERWORKING}, -- shadowprowlers chestguard
	["shadowprowler chest"] = {42731, CraftPrefix.LEATHERWORKING}, -- shadowprowlers chestguard
	["netherdrake helm"] = {35572, CraftPrefix.LEATHERWORKING},
	["netherdrake gloves"] = {35573, CraftPrefix.LEATHERWORKING},
	["living dragonscale helm"] = {35564, CraftPrefix.LEATHERWORKING},
	["hood of primal life"] = {35561, CraftPrefix.LEATHERWORKING},
	["gloves of the living touch"] = {35562, CraftPrefix.LEATHERWORKING},
	["earthen netherscale boots"] = {35567, CraftPrefix.LEATHERWORKING},
	["cobrascale hood"] = {35558, CraftPrefix.LEATHERWORKING},
	["cobrascale gloves"] = {35559, CraftPrefix.LEATHERWORKING},
	["drums of battle"] = {35543, CraftPrefix.LEATHERWORKING},
	["heavy clefthoof vest"] = {32495, CraftPrefix.LEATHERWORKING},
	["felstalker breastplate"] = {32500, CraftPrefix.LEATHERWORKING},
	["felstalker bracer"] = {32499, CraftPrefix.LEATHERWORKING},
	["cloak of darkness"] = {42546, CraftPrefix.LEATHERWORKING},
	["heavy clefthoof leggings"] = {32496, CraftPrefix.LEATHERWORKING},
	["heavy clefthoof boots"] = {32497, CraftPrefix.LEATHERWORKING},
	["stylin purple hat"] = {32485, CraftPrefix.LEATHERWORKING},
	["stylish purple hat"] = {32485, CraftPrefix.LEATHERWORKING}, -- stylin purple hat
	["styling purple hat"] = {32485, CraftPrefix.LEATHERWORKING}, -- stylin purple hat
	["purple hat"] = {32485, CraftPrefix.LEATHERWORKING}, -- stylin purple hat
	["stylin jungle hat"] = {32489, CraftPrefix.LEATHERWORKING},
	["stylin crimson hat"] = {32488, CraftPrefix.LEATHERWORKING},
	["stylin adventure hat"] = {32487, CraftPrefix.LEATHERWORKING},
	["netherfury boots"] = {32503, CraftPrefix.LEATHERWORKING},
	["flamescale leggings"] = {35529, CraftPrefix.LEATHERWORKING},
	["flamescale boots"] = {35528, CraftPrefix.LEATHERWORKING},
	["flamescale belt"] = {35531, CraftPrefix.LEATHERWORKING},
	["felstalker belt"] = {32498, CraftPrefix.LEATHERWORKING},
	["fel leather leggings"] = {32494, CraftPrefix.LEATHERWORKING},
	["fel leather boots"] = {32493, CraftPrefix.LEATHERWORKING},
	["enchanted felscale leggings"] = {35525, CraftPrefix.LEATHERWORKING},
	["enchanted felscale gloves"] = {35526, CraftPrefix.LEATHERWORKING},
	["enchanted felscale boots"] = {35527, CraftPrefix.LEATHERWORKING},
	["enchanted clefthoof leggings"] = {35532, CraftPrefix.LEATHERWORKING},
	["enchanted clefthoof gloves"] = {35533, CraftPrefix.LEATHERWORKING},
	["enchanted clefthoof boots"] = {35534, CraftPrefix.LEATHERWORKING},
	["blastguard pants"] = {35535, CraftPrefix.LEATHERWORKING},
	["blastguard boots"] = {35536, CraftPrefix.LEATHERWORKING},
	["blastguard belt"] = {35537, CraftPrefix.LEATHERWORKING},
	["glove reinforcements"] = {44770, CraftPrefix.LEATHERWORKING},
	["drums of restoration"] = {35539, CraftPrefix.LEATHERWORKING},
	["drums of speed"] = {35544, CraftPrefix.LEATHERWORKING},
	["netherfury leggings"] = {32502, CraftPrefix.LEATHERWORKING},
	["netherfury belt"] = {32501, CraftPrefix.LEATHERWORKING},
	["fel leather gloves"] = {32490, CraftPrefix.LEATHERWORKING},
	["drums of war"] = {35540, CraftPrefix.LEATHERWORKING},
	["scaled draenic boots"] = {32469, CraftPrefix.LEATHERWORKING},
	["felscale breastplate"] = {32465, CraftPrefix.LEATHERWORKING},
	["primalstorm breastplate"] = {36077, CraftPrefix.LEATHERWORKING},
	["living crystal breastplate"] = {36078, CraftPrefix.LEATHERWORKING},
	["golden dragonstrike breastplate"] = {36079, CraftPrefix.LEATHERWORKING},
	["wild draenish vest"] = {32481, CraftPrefix.LEATHERWORKING},
	["thick draenic vest"] = {32473, CraftPrefix.LEATHERWORKING},
	["scaled draenic vest"] = {32468, CraftPrefix.LEATHERWORKING},
	["wild draenish leggings"] = {32480, CraftPrefix.LEATHERWORKING},
	["thick draenic boots"] = {32472, CraftPrefix.LEATHERWORKING},
	["felscale pants"] = {32464, CraftPrefix.LEATHERWORKING},
	["thick draenic pants"] = {32471, CraftPrefix.LEATHERWORKING},
	["wild draenish gloves"] = {32479, CraftPrefix.LEATHERWORKING},
	["scaled draenic gloves"] = {32467, CraftPrefix.LEATHERWORKING},
	["felscale boots"] = {32463, CraftPrefix.LEATHERWORKING},
	["wolfshead helm"] = {10621, CraftPrefix.LEATHERWORKING},
	-- Tailoring
	["primal mooncloth bag"] = {26763, CraftPrefix.TAILORING},
	["ebon shadowbag"] = {26759, CraftPrefix.TAILORING},
	["whitemend hood"] = {31454, CraftPrefix.TAILORING},
	["swiftheal wraps"] = {41207, CraftPrefix.TAILORING},
	["swiftheal mantle"] = {41208, CraftPrefix.TAILORING},
	["spellstrike pants"] = {31452, CraftPrefix.TAILORING},
	["spellstrike hood"] = {31455, CraftPrefix.TAILORING},
	["spellfire robe"] = {26754, CraftPrefix.TAILORING},
	["soulguard slippers"] = {40020, CraftPrefix.TAILORING},
	["soulguard leggings"] = {40023, CraftPrefix.TAILORING},
	["soulguard girdle"] = {40024, CraftPrefix.TAILORING},
	["soulguard bracers"] = {40021, CraftPrefix.TAILORING},
	["soulcloth vest"] = {26781, CraftPrefix.TAILORING},
	["primal mooncloth robe"] = {26762, CraftPrefix.TAILORING},
	["nights end"] = {40060, CraftPrefix.TAILORING},
	["shadow res cloak"] = {40060, CraftPrefix.TAILORING}, -- nights end
	["shadow resist cloak"] = {40060, CraftPrefix.TAILORING}, -- nights end
	["shadow resistance cloak"] = {40060, CraftPrefix.TAILORING}, -- nights end
	["mantle of nimble thought"] = {41206, CraftPrefix.TAILORING},
	["frozen shadoweave robe"] = {26758, CraftPrefix.TAILORING},
	["bracers of nimble thought"] = {41205, CraftPrefix.TAILORING},
	["boots of the long road"] = {36318, CraftPrefix.TAILORING},
	["boots of blasting"] = {36317, CraftPrefix.TAILORING},
	["belt of the long road"] = {36316, CraftPrefix.TAILORING},
	["belt of blasting"] = {36315, CraftPrefix.TAILORING},
	["battlecast pants"] = {31453, CraftPrefix.TAILORING},
	["battlecast hood"] = {31456, CraftPrefix.TAILORING},
	["flameheart vest"] = {37884, CraftPrefix.TAILORING},
	["arcanoweave robe"] = {26784, CraftPrefix.TAILORING},
	["sunfire robe"] = {46130, CraftPrefix.TAILORING},
	["sunfire handwraps"] = {46128, CraftPrefix.TAILORING},
	["robe of eternal light"] = {46131, CraftPrefix.TAILORING},
	["hands of eternal light"] = {46129, CraftPrefix.TAILORING},
	["vengeance wrap"] = {31449, CraftPrefix.TAILORING},
	["unyielding girdle"] = {31442, CraftPrefix.TAILORING},
	["spellfire gloves"] = {26753, CraftPrefix.TAILORING},
	["soulcloth shoulders"] = {26780, CraftPrefix.TAILORING},
	["resolute cape"] = {31448, CraftPrefix.TAILORING},
	["primal mooncloth shoulders"] = {26761, CraftPrefix.TAILORING},
	["manaweave cloak"] = {31450, CraftPrefix.TAILORING},
	["girdle of ruination"] = {31443, CraftPrefix.TAILORING},
	["frozen shadoweave boots"] = {26757, CraftPrefix.TAILORING},
	["black belt of knowledge"] = {31444, CraftPrefix.TAILORING},
	["imbued netherweave tunic"] = {26778, CraftPrefix.TAILORING},
	["imbued netherweave robe"] = {26777, CraftPrefix.TAILORING},
	["flameheart gloves"] = {37883, CraftPrefix.TAILORING},
	["arcanoweave boots"] = {26783, CraftPrefix.TAILORING},
	["spellfire belt"] = {26752, CraftPrefix.TAILORING},
	["soulcloth gloves"] = {26779, CraftPrefix.TAILORING},
	["primal mooncloth belt"] = {26760, CraftPrefix.TAILORING},
	["frozen shadoweave shoulders"] = {26756, CraftPrefix.TAILORING},
	["white remedy cape"] = {31441, CraftPrefix.TAILORING},
	["unyielding bracers"] = {31434, CraftPrefix.TAILORING},
	["imbued netherweave boots"] = {26776, CraftPrefix.TAILORING},
	["flameheart bracers"] = {37882, CraftPrefix.TAILORING},
	["cloak of the black void"] = {31438, CraftPrefix.TAILORING},
	["cloak of eternity"] = {31440, CraftPrefix.TAILORING},
	["cloak of arcane evasion"] = {37873, CraftPrefix.TAILORING},
	["cloak of arcane res"] = {37873, CraftPrefix.TAILORING}, -- cloak of arcane evasion
	["cloak of arcane resist"] = {37873, CraftPrefix.TAILORING}, -- cloak of arcane evasion
	["cloak of arcane resistance"] = {37873, CraftPrefix.TAILORING}, -- cloak of arcane evasion
	["arcane cloak"] = {37873, CraftPrefix.TAILORING}, -- cloak of arcane evasion
	["arcane res cloak"] = {37873, CraftPrefix.TAILORING}, -- cloak of arcane evasion
	["arcane resist cloak"] = {37873, CraftPrefix.TAILORING}, -- cloak of arcane evasion
	["arcane resistance cloak"] = {37873, CraftPrefix.TAILORING}, -- cloak of arcane evasion
	["bracers of havok"] = {31435, CraftPrefix.TAILORING},
	["blackstrike bracers"] = {31437, CraftPrefix.TAILORING},
	["arcanoweave bracers"] = {26782, CraftPrefix.TAILORING},
	["spellcloth"] = {31373, CraftPrefix.TAILORING},
	["shadowcloth"] = {36686, CraftPrefix.TAILORING},
	["primal mooncloth"] = {26751, CraftPrefix.TAILORING},
	["netherweave tunic"] = {26774, CraftPrefix.TAILORING},
	["bolt of soulcloth"] = {26750, CraftPrefix.TAILORING},
	["netherweave robe"] = {26773, CraftPrefix.TAILORING},
	["imbued netherweave pants"] = {26775, CraftPrefix.TAILORING},
	["netherweave boots"] = {26772, CraftPrefix.TAILORING},
	["netherweave pants"] = {26771, CraftPrefix.TAILORING},
	["netherweave gloves"] = {26770, CraftPrefix.TAILORING},
	["netherweave bracers"] = {26764, CraftPrefix.TAILORING},
	["netherweave belt"] = {26765, CraftPrefix.TAILORING},
	["tuxedo jacket"] = {12093, CraftPrefix.TAILORING},
	["tuxedo pants"] = {12089, CraftPrefix.TAILORING},
	["tuxedo shirt"] = {12085, CraftPrefix.TAILORING},
}

-- developement command to build craftNameList easily
-- _G.SlashCmdList["CRAFTTABLE"] = function(link)
--    if not link or link == "" then return end
--    local id, name = link:match(":(%d+).+%[(.+)]")
--    if id and name then
--       name = name:gsub("%p+", ""):gsub("%s+", " "):lower()
--       DEFAULT_CHAT_FRAME:AddMessage(string.format('["%s"] = {%s, CraftPrefix.ENGINEERING},', name, id))
--    end
-- end
-- _G.SLASH_CRAFTTABLE1 = "/crafttable"
